/* Copyright 2003-2005 Charles Robert Simpson, Jr.
 *
 * This file is part of NETI@home.
 * 
 * NETI@home is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * NETI@home is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with NETI@home; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// Call repaint() every second
// Create a linked list of points to draw
// Clear the list after every repaint
// probably need a clear button
// maybe double-click will start a graphical traceroute (and a traceroute that we'll keep)
// should draw a rectangle behind the text
// Need error checking for netgeoclient
// Need to cache data from netgeo

import java.awt.*; 
import java.awt.image.*;
import java.awt.event.*; 
import java.awt.geom.*; 
import java.io.*;
import java.net.*;
import java.util.*;

class NETIMap extends Frame implements ActionListener, MouseMotionListener, MouseListener { 
	Image newImage;
	Image offScreenImage;
	Graphics offScreenGC;
	int w = 1080;
	int h = 539;
	int pointWidth;
	float aLat;
	float aLon;
	float bLat;
	float bLon;
	float top_lat;
	float top_lon;
	float bot_lat;
	float bot_lon;
	Hashtable pendingPoints;
	String nameText = "";
	String domainText = "";
	String targetText = "";
	String cityText = "";
	String stateText = "";
	String countryText = "";
	int mouseX = 0;
	int mouseY = 0;
	Toolkit tk;
	Button clearButton;

	public NETIMap() {
		super("NETIMap: Locations You Have Recently Contacted");
		tk = Toolkit.getDefaultToolkit();
		newImage = tk.getImage("world100.gif");
		addMouseListener(this);
		addMouseMotionListener(this);
		setSize(w,h);

		pointWidth = 7;
		pendingPoints = new Hashtable();

		top_lat = 90;
		top_lon = -170;
		bot_lat = -90;
		bot_lon = 190;

		bLon = top_lon;
		bLat = top_lat;
		aLon = (bot_lon-top_lon)/w;
		aLat = (bot_lat-top_lat)/h;
	}

	public void update(Graphics g) {
		paint(g);
	}

	public void paint(Graphics g) { 
		NetiPoint p;
		offScreenImage = createImage(w,h);
		offScreenGC = offScreenImage.getGraphics();

		offScreenGC.drawImage(newImage,0,0,this);



		offScreenGC.setColor(Color.red);

		Enumeration ePoints = pendingPoints.elements();
		while(ePoints.hasMoreElements()) {
			p = (NetiPoint)ePoints.nextElement();
			offScreenGC.fillOval(p.x - (pointWidth/2),p.y - (pointWidth/2),pointWidth,pointWidth);
		}


		offScreenGC.setFont(new Font("Dialog", Font.BOLD, 14));
		offScreenGC.setColor(Color.blue);
		offScreenGC.drawString(nameText, mouseX + 15, mouseY);
		offScreenGC.drawString(domainText, mouseX + 15, mouseY + 15);
		offScreenGC.drawString(targetText, mouseX + 15, mouseY + 30);
		offScreenGC.drawString(cityText, mouseX + 15, mouseY + 45);
		offScreenGC.drawString(stateText, mouseX + 15, mouseY + 60);
		offScreenGC.drawString(countryText, mouseX + 15, mouseY + 75);




		g.drawImage(offScreenImage, 0,0,getBackground(), this);
	} 

	public void mouseDragged(MouseEvent e) {
	}

	public void mouseEntered(MouseEvent e) {
	}

	public void mouseExited(MouseEvent e) {
	}

	public void mousePressed(MouseEvent e) {
	}

	public void mouseReleased(MouseEvent e) {
	}

	// For traceroute
	public void mouseClicked(MouseEvent e) {
	}

	public void mouseMoved(MouseEvent e) {
		Point mouseP = e.getPoint();
		mouseX = mouseP.x;
		mouseY = mouseP.y;
		Enumeration ePoints = pendingPoints.elements();
		while(ePoints.hasMoreElements()) {
			NetiPoint pt = (NetiPoint)ePoints.nextElement();
			if(pt.withinBoundary(mouseP)) {
				nameText = (String)pt.h.get("NAME");
				domainText = (String)pt.h.get("DOMAIN_GUESS");
				targetText = (String)pt.h.get("TARGET");
				cityText = (String)pt.h.get("CITY");
				stateText = (String)pt.h.get("STATE");
				countryText = (String)pt.h.get("COUNTRY");
				repaint();
				return;
			}
		}
		nameText = "";
		domainText = "";
		targetText = "";
		cityText = "";
		stateText = "";
		countryText = "";
		repaint();
	}

	public NetiPoint latLonToPoint(float lat, float lon) {    
		NetiPoint p = new NetiPoint();
		p.y = new Float((lat-bLat)/aLat + 0.5).intValue();
		p.x = new Float((lon-bLon)/aLon + 0.5).intValue();
		return p;
	}

	public void actionPerformed(ActionEvent e) {
		repaint();
	}

	public static void main(String args[]) throws IOException { 
		NetiPoint pt;// = new NetiPoint();
		NETIMap map = new NETIMap();
		byte[] buf;

		// UDP stuff
		DatagramSocket ipSocket = new DatagramSocket(1557, InetAddress.getByName(null));
		DatagramPacket packet;
		// End UDP stuff

		map.addWindowListener(new WindowAdapter() { 
			public void windowClosing(WindowEvent e) { 
				System.exit(0); 
			} 
		}); 

		map.setLayout(new GridLayout(1,1,5,5));

		map.setVisible(true); 

		String input;
		NetGeoClient netgeo = new NetGeoClient("plot_AS_loc/1.2.3");
		Hashtable h;
		while(true) {
			buf = new byte[256];
			packet = new DatagramPacket(buf, buf.length);
			ipSocket.receive(packet);
			input = new String(packet.getData(), 0, packet.getLength());
			try {
				h = netgeo.getRecord(input);
			}
			catch(Exception e) {
				continue;
			}
			if(((String)h.get("STATUS")).equals("OK")) {
				pt = map.latLonToPoint(NetGeoClient.getLat(h), NetGeoClient.getLong(h));
				pt.h = h;
				map.pendingPoints.put(new Point(pt.x, pt.y), pt);
				map.repaint();
			}
		}
	} 
} 

class NetiPoint {
	public NetiPoint() {
	}

	public NetiPoint(Point p) {
		x = p.x;
		y = p.y;
	}

	public boolean withinBoundary(Point p) {
		if(p.x >= x - 3 && p.x <= x + 3 && p.y >= y - 3 && p.y <= y + 3) {
			return true;
		}
		else {
			return false;
		}
	}

	int x;
	int y;
	Hashtable h;
}

