/* Copyright 2003-2005 Charles Robert Simpson, Jr.
 *
 * This file is part of NETI@home.
 * 
 * NETI@home is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * NETI@home is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with NETI@home; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// Need to find a way to make sure only one dialog is open at a time

#define _WINSOCKAPI_   /* Prevent inclusion of winsock.h in windows.h */
#include <windows.h>  // main Windows header
#include <windowsx.h> // message cracker macros, etc.
#include <shellapi.h> // Shell32 api
#include <stdio.h>
#include <pcap.h>
#include "NETITray.h"
#define UWM_SYSTRAY (WM_USER + 1) // Sent to us by the systray
#define MAX_WIN_IF_NAME_LEN 511
#define CANT_GET_INTERFACE_LIST 0	/* error getting list */
#define NO_INTERFACES_FOUND     1	/* list is empty */
#define DEST_ADDR "neti.ece.gatech.edu"
#define UPDATEALERT_PORT 558
#define NETI_VERSION 20

LRESULT CALLBACK wndProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam);
BOOL CALLBACK DeleteAboutProc(HWND hwndDlg, UINT message, WPARAM wParam, LPARAM lParam);
BOOL CALLBACK PropertiesProc(HWND hwndDlg, UINT message, WPARAM wParam, LPARAM lParam);
BOOL AddTaskbarIcon(HWND hwnd);
BOOL ChangeTaskbarIcon(HWND hwnd);
BOOL WINAPI InitLogfileComboBox(HWND hwndCombo);
BOOL WINAPI InitGeolocationComboBox(HWND hwndCombo);
BOOL WINAPI InitInterfaceComboBox(HWND hwndCombo);
int getPrivacy();
int getLogfileSize();
char * getInterface();
int getGeolocation();
int getUSZip();
int getIdentifier();
char * getEmail();
int getLatestVersion();
int setProperties(int privacylevel, int logsize, int geolocation, int intrfc, char *zip, char *email);
if_info_t * get_interface_list(int *err, char *err_str);
if_info_t * get_interface_list_findalldevs(int *err, char *err_str);
void free_interface_list(if_info_t *if_list);
int init_winsock(void);

HINSTANCE ghInst;
HWND bighwnd;
HANDLE HProperties = NULL;
HANDLE HExit = NULL;
char netidir[80];
char filename[80];
DWORD dwBufLen = 80;
int servicestarted = 0;
int updatealerted = 0;
int updateavailable = 0;

int WINAPI WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpszCmdLine, int nCmdShow) {
	HWND hwnd;
	WNDCLASSEX wc;
	MSG msg;
	char *classname = "NETI.NOTIFYICONDATA.hWnd";
	ghInst = hInstance;
	HKEY hKey;
	LONG lRet;
	int netiver = -1;
	// Low priority -- don't soak up as many CPU cycles.
	// This won't make a difference unless we are doing background processing
	// in this process.
	SetPriorityClass(GetCurrentProcess(), IDLE_PRIORITY_CLASS);

	// Start winsock
	init_winsock();

	/* Create Events to communicate to NETI with */
	HProperties = OpenEvent(EVENT_MODIFY_STATE, FALSE, "NetiUpdatePropertiesEvent");
	if(HProperties == NULL) {
		servicestarted = 0;
	}
	else {
		servicestarted = 1;
	}
	HExit = OpenEvent(EVENT_MODIFY_STATE, FALSE, "NetiExitEvent");
	if(HExit == NULL) {
		servicestarted = 0;
	}
	else {
		servicestarted = 1;
	}

	if(!updatealerted) {
		// Check for Updates
		netiver = getLatestVersion();
		if(netiver == -1) {
			updatealerted = 0;
		}
		else if(netiver > NETI_VERSION) {
			// Update Available
			updateavailable = 1;
			updatealerted = 1;
		}
		else {
			updatealerted = 1;
		}
	}

	if(RegOpenKeyEx(HKEY_LOCAL_MACHINE, TEXT("Software\\NETI@home"), 0, KEY_QUERY_VALUE, &hKey) != ERROR_SUCCESS) {
		::MessageBox(NULL, "NETI@home: Error Accessing System Registry!", "Error", MB_OK);
		return -1;
	}
	lRet = RegQueryValueEx(hKey, TEXT(""), NULL, NULL, (LPBYTE)netidir, &dwBufLen);
	RegCloseKey(hKey);
	if(lRet != ERROR_SUCCESS) {
		::MessageBox(NULL, "NETI@home: Error Reading System Registry!", "Error", MB_OK);
		return -1;
	}
	// Append "\\neti.conf" to filename
	strncpy(filename, netidir, dwBufLen);
	filename[dwBufLen] = '\0';
	strncat(filename, "\\neti.conf", 11);

	/* Open Properties File */
	FILE *fpt;
	if((fpt = fopen(filename, "r+")) == NULL) {
		::MessageBox(NULL, "Could Not Open Properties File", "Error", MB_OK);
		return -1;
	}
	fclose(fpt);

	/* Create a window class for the window that receives systray notifications.
	* The window will never be displayed, although there's no reason it couldn't
	* be (it just wouldn't be very useful in this program, and in most others).
	*/
	wc.cbSize = sizeof(WNDCLASSEX);
	wc.style = 0;
	wc.lpfnWndProc = wndProc;
	wc.cbClsExtra = wc.cbWndExtra = 0;
	wc.hInstance = hInstance;
	if(servicestarted) {
		if(updateavailable) {
			wc.hIcon = LoadIcon(hInstance, MAKEINTRESOURCE(IDI_44));
		}
		else {
			wc.hIcon = LoadIcon(hInstance, MAKEINTRESOURCE(IDI_42));
		}
	}
	else {
		if(updateavailable) {
			wc.hIcon = LoadIcon(hInstance, MAKEINTRESOURCE(IDI_45));
		}
		else {
			wc.hIcon = LoadIcon(hInstance, MAKEINTRESOURCE(IDI_43));
		}
	}
	wc.hCursor = LoadCursor(NULL, IDC_ARROW);
	wc.hbrBackground = (HBRUSH)(COLOR_WINDOW + 1);
	wc.lpszMenuName = NULL;
	wc.lpszClassName = classname;
	if(servicestarted) {
		if(updateavailable) {
			wc.hIconSm = LoadIcon(hInstance, MAKEINTRESOURCE(IDI_44));
		}
		else {
			wc.hIconSm = LoadIcon(hInstance, MAKEINTRESOURCE(IDI_42));
		}
	}
	else {
		if(updateavailable) {
			wc.hIconSm = LoadIcon(hInstance, MAKEINTRESOURCE(IDI_45));
		}
		else {
			wc.hIconSm = LoadIcon(hInstance, MAKEINTRESOURCE(IDI_43));
		}
	}
	RegisterClassEx(&wc);
	// Create window. Note that WS_VISIBLE is not used, and window is never shown
	hwnd = CreateWindowEx(0, classname, classname, WS_POPUP, CW_USEDEFAULT, 0, CW_USEDEFAULT, 0, NULL, NULL, hInstance, NULL);
	bighwnd = hwnd;

	AddTaskbarIcon(hwnd);

	if(SetTimer(hwnd, IDT_TIMER, 5000, (TIMERPROC) NULL) == 0) {
		::MessageBox(NULL, "NETI@home: Error Creating Timer!", "Error", MB_OK);
		return -1;
	}

	while (GetMessage(&msg, NULL, 0, 0)) {
		TranslateMessage(&msg);
		DispatchMessage(&msg);
	}

	return msg.wParam;
}

BOOL AddTaskbarIcon(HWND hwnd) {
	NOTIFYICONDATA nid;

	// Fill out NOTIFYICONDATA structure
	nid.cbSize = sizeof(NOTIFYICONDATA); // size
	nid.hWnd = hwnd; // window to receive notifications
	nid.uID = 1;     // application-defined ID for icon (can be any UINT value)
	nid.uFlags = NIF_MESSAGE |  // nid.uCallbackMessage is valid, use it
				 NIF_ICON |     // nid.hIcon is valid, use it
				 NIF_TIP;       // nid.szTip is valid, use it
	nid.uCallbackMessage = UWM_SYSTRAY; // message sent to nid.hWnd
	if(servicestarted) {
		if(updateavailable) {
			nid.hIcon = LoadIcon(ghInst, MAKEINTRESOURCE(IDI_44));
			strcpy(nid.szTip, "NETI@home - An Update is Available");
		}
		else {
			nid.hIcon = LoadIcon(ghInst, MAKEINTRESOURCE(IDI_42));
			strcpy(nid.szTip, "NETI@home");
		}
	}
	else {
		if(updateavailable) {
			nid.hIcon = LoadIcon(ghInst, MAKEINTRESOURCE(IDI_45));
			strcpy(nid.szTip, "NETI@home - Not Currently Running - An Update is Available");
		}
		else {
			nid.hIcon = LoadIcon(ghInst, MAKEINTRESOURCE(IDI_43));
			strcpy(nid.szTip, "NETI@home - Not Currently Running");
		}
	}

	// NIM_ADD: Add icon; NIM_DELETE: Remove icon; NIM_MODIFY: modify icon
	return Shell_NotifyIcon(NIM_ADD, &nid); // This adds the icon
}

BOOL ChangeTaskbarIcon(HWND hwnd) {
	NOTIFYICONDATA nid;

	// Fill out NOTIFYICONDATA structure
	nid.cbSize = sizeof(NOTIFYICONDATA); // size
	nid.hWnd = hwnd; // window to receive notifications
	nid.uID = 1;     // application-defined ID for icon (can be any UINT value)
	nid.uFlags = NIF_MESSAGE |  // nid.uCallbackMessage is valid, use it
				 NIF_ICON |     // nid.hIcon is valid, use it
				 NIF_TIP;       // nid.szTip is valid, use it
	nid.uCallbackMessage = UWM_SYSTRAY; // message sent to nid.hWnd
	if(servicestarted) {
		if(updateavailable) {
			nid.hIcon = LoadIcon(ghInst, MAKEINTRESOURCE(IDI_44));
			strcpy(nid.szTip, "NETI@home - An Update is Available");
		}
		else {
			nid.hIcon = LoadIcon(ghInst, MAKEINTRESOURCE(IDI_42));
			strcpy(nid.szTip, "NETI@home");
		}
	}
	else {
		if(updateavailable) {
			nid.hIcon = LoadIcon(ghInst, MAKEINTRESOURCE(IDI_45));
			strcpy(nid.szTip, "NETI@home - Not Currently Running - An Update is Available");
		}
		else {
			nid.hIcon = LoadIcon(ghInst, MAKEINTRESOURCE(IDI_43));
			strcpy(nid.szTip, "NETI@home - Not Currently Running");
		}
	}

	// NIM_ADD: Add icon; NIM_DELETE: Remove icon; NIM_MODIFY: modify icon
	return Shell_NotifyIcon(NIM_MODIFY, &nid); // This adds the icon
}

LRESULT CALLBACK wndProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam) {
	static UINT s_uTaskbarRestart;
	POINT pt;
	HMENU hmenu, hpopup;
	NOTIFYICONDATA nid;
	int lastservicestarted = 0;
	int lastupdateavailable = 0;
	char netiexe[80];
	int netiver = -1;

	switch (message) {
		case WM_CREATE:
			s_uTaskbarRestart = RegisterWindowMessage(TEXT("TaskbarCreated"));
			break;

		case WM_DESTROY:
			nid.cbSize = sizeof(NOTIFYICONDATA);
			nid.hWnd = hwnd;
			nid.uID = 1;
			nid.uFlags = NIF_TIP; // not really sure what to put here, but it works
			Shell_NotifyIcon(NIM_DELETE, &nid); // This removes the icon
			KillTimer(hwnd, IDT_TIMER);
			PostQuitMessage(0);
			return TRUE;


		case WM_TIMER:
			switch(wParam) {
				case IDT_TIMER:
					// Check service
					lastservicestarted = servicestarted;
					lastupdateavailable = updateavailable;
					if(HProperties != NULL) {
						CloseHandle(HProperties);
					}
					HProperties = OpenEvent(EVENT_MODIFY_STATE, FALSE, "NetiUpdatePropertiesEvent");
					if(HProperties == NULL) {
						servicestarted = 0;
					}
					else {
						servicestarted = 1;
					}
					if(HExit != NULL) {
						CloseHandle(HExit);
					}
					HExit = OpenEvent(EVENT_MODIFY_STATE, FALSE, "NetiExitEvent");
					if(HExit == NULL) {
						servicestarted = 0;
					}
					else {
						servicestarted = 1;
					}
					if(!updatealerted) {
						// Check for Updates
						netiver = getLatestVersion();
						if(netiver == -1) {
							updatealerted = 0;
						}
						else if(netiver > NETI_VERSION) {
							// Update Available
							updateavailable = 1;
							updatealerted = 1;
						}
						else {
							updatealerted = 1;
						}
					}
					if((lastservicestarted != servicestarted) || (lastupdateavailable != updateavailable)) {
						ChangeTaskbarIcon(hwnd);
					}
					break;
			}
			break;

		case UWM_SYSTRAY: // We are being notified of mouse activity over the icon
			switch (lParam) {
				case WM_RBUTTONUP: // Let's track a popup menu
					GetCursorPos(&pt);
					if(servicestarted) {
						hmenu = LoadMenu(ghInst, MAKEINTRESOURCE(IDM_CONTEXTMAIN));
					}
					else {
						hmenu = LoadMenu(ghInst, MAKEINTRESOURCE(IDM_CONTEXTMAIN1));
					}
					hpopup = GetSubMenu(hmenu, 0);

					/* SetForegroundWindow and the ensuing null PostMessage is a
					* workaround for a Windows 95 bug (see MSKB article Q135788,
					* http://www.microsoft.com/kb/articles/q135/7/88.htm, I think).
					* In typical Microsoft style this bug is listed as "by design".
					* SetForegroundWindow also causes our MessageBox to pop up in front
					* of any other application's windows.
					*/
					SetForegroundWindow(hwnd);
					/* We specifiy TPM_RETURNCMD, so TrackPopupMenu returns the menu
					* selection instead of returning immediately and our getting a
					* WM_COMMAND with the selection. You don't have to do it this way.
					*/
					switch (TrackPopupMenu(hpopup,            // Popup menu to track
						TPM_RETURNCMD |		// Return menu code
						TPM_RIGHTBUTTON,	// Track right mouse button?
						pt.x, pt.y,			// screen coordinates
						0,					// reserved
						hwnd,				// owner
						NULL))				// LPRECT user can click in
											// without dismissing menu
					{
						case IDM_EXIT:
							WSACleanup();
							DestroyWindow(hwnd);
							break;
						case ID_YOU_STOPNETI:
							// Do the Exit Event thing
							if(HExit != NULL) {
								SetEvent(HExit);
							}
							break;
						case ID_YOU_STARTNETI:
							// Do the start stuff
							STARTUPINFO si;
							PROCESS_INFORMATION pi;
							ZeroMemory(&si, sizeof(si));
							si.cb = sizeof(si);
							si.dwFlags = STARTF_USESHOWWINDOW;
							si.wShowWindow = SW_HIDE;
							ZeroMemory(&pi, sizeof(pi));
							ZeroMemory(netiexe, sizeof(netiexe));
							strcpy(netiexe, "\"");
							strncat(netiexe, netidir, dwBufLen);
							strncat(netiexe, "\\neti.exe\"", 12);
							if(!CreateProcess(NULL, netiexe, NULL, NULL, FALSE, 0, NULL, NULL, &si, &pi)) {
								::MessageBox(NULL, "Could Not Start NETI@home", "Error", MB_OK);
							}
							else {
								// Need to close handles
								CloseHandle(pi.hProcess);
								CloseHandle(pi.hThread);
							}
							break;
						case IDM_MESSAGEBOX:
							DialogBox(ghInst, MAKEINTRESOURCE(IDD_PROPERTIES), hwnd, (DLGPROC)PropertiesProc);
							break;
						case IDM_ABOUTBOX:
							DialogBox(ghInst, MAKEINTRESOURCE(IDD_ABOUTBOX), hwnd, (DLGPROC)DeleteAboutProc);
							break;
					}
					PostMessage(hwnd, 0, 0, 0); // see above
					DestroyMenu(hmenu); // Delete loaded menu and reclaim its resources
					break;

				case WM_LBUTTONDBLCLK:
					SetForegroundWindow(hwnd); // Our MessageBox pops up in front
					if(updateavailable) {
						::MessageBox(hwnd, "You are using an older version of NETI@home.\r\nAn update is available at http://neti.gatech.edu", "NETI@home Update Available", MB_OK | MB_ICONWARNING);
					}
					DialogBox(ghInst, MAKEINTRESOURCE(IDD_PROPERTIES), hwnd, (DLGPROC)PropertiesProc);
					break;
				// Other mouse messages: WM_MOUSEMOVE, WM_MBUTTONDOWN, etc.
			}
			break;
		default:
			if(message == s_uTaskbarRestart) {
				AddTaskbarIcon(hwnd);
			}
			break;
	}
	return DefWindowProc(hwnd, message, wParam, lParam);
}

BOOL CALLBACK DeleteAboutProc(HWND hwndDlg, UINT message, WPARAM wParam, LPARAM lParam) { 
	switch (message) { 
		case WM_COMMAND: 
			switch (LOWORD(wParam)) { 
				case IDOK: 
					EndDialog(hwndDlg, wParam); 
					return TRUE; 
			} 
	} 
	return FALSE; 
}

BOOL CALLBACK PropertiesProc(HWND hwndDlg, UINT message, WPARAM wParam, LPARAM lParam) {
	int results;
	int results2;
	int results3;
	int results4;
	char zip[10];
	char email[256];
	char *devname = NULL;
	char *tempemail = NULL;
	if_info_t *tempdev = NULL;
	if_info_t *devhead = NULL;
	int devcount = 0;
	int interr;
	char errorbuf[PCAP_ERRBUF_SIZE];
	switch (message) { 
		case WM_INITDIALOG:
			// Initialize Combo Boxes
			InitLogfileComboBox(GetDlgItem(hwndDlg, IDC_COMBO1));
			InitGeolocationComboBox(GetDlgItem(hwndDlg, IDC_COMBO2));
			InitInterfaceComboBox(GetDlgItem(hwndDlg, IDC_COMBO3));
			// Set default selections (or previous)
			// Privacy Setting
			results = getPrivacy();
			if(results == -1) {
				CheckRadioButton(hwndDlg, IDC_RADIO3, IDC_RADIO5, IDC_RADIO4);
				::MessageBox(NULL, "getPrivacy Error (neti.conf nonexistent or misconfigured)", "Error", MB_OK);
			}
			else if(results == 0) {
				CheckRadioButton(hwndDlg, IDC_RADIO3, IDC_RADIO5, IDC_RADIO3);
			}
			else if(results == 1) {
				CheckRadioButton(hwndDlg, IDC_RADIO3, IDC_RADIO5, IDC_RADIO4);
			}
			else if(results == 2) {
				CheckRadioButton(hwndDlg, IDC_RADIO3, IDC_RADIO5, IDC_RADIO5);
			}
			else {
				CheckRadioButton(hwndDlg, IDC_RADIO3, IDC_RADIO5, IDC_RADIO3);
				::MessageBox(NULL, "getPrivacy Error (neti.conf nonexistent or misconfigured)", "Error", MB_OK);
			}
			// Sets default selection of logfile size, is an array starting at zero
			// Set the next-to-the-last argument to a value between 0 and 4
			// Maximum Logfile Size
			results = getLogfileSize();
			if(results <= 0) {
				::MessageBox(NULL, "getLogfileSize Error (neti.conf nonexistent or misconfigured)", "Error", MB_OK);
				// use default size (1 MByte)
				SendMessage(GetDlgItem(hwndDlg, IDC_COMBO1), CB_SETCURSEL, 3, 0);
			}
			else if(results <= 1000) {
				// 1 KByte
				SendMessage(GetDlgItem(hwndDlg, IDC_COMBO1), CB_SETCURSEL, 0, 0);
			}
			else if(results <= 10000) {
				// 10 KBytes
				SendMessage(GetDlgItem(hwndDlg, IDC_COMBO1), CB_SETCURSEL, 1, 0);
			}
			else if(results <= 100000) {
				// 100 KBytes
				SendMessage(GetDlgItem(hwndDlg, IDC_COMBO1), CB_SETCURSEL, 2, 0);
			}
			else if(results <= 1000000) {
				// 1 MByte
				SendMessage(GetDlgItem(hwndDlg, IDC_COMBO1), CB_SETCURSEL, 3, 0);
			}
			else {
				// 10 MBytes
				SendMessage(GetDlgItem(hwndDlg, IDC_COMBO1), CB_SETCURSEL, 4, 0);
			}
			// Geographical Location
			results = getGeolocation();
			if(results < 0) {
				// On error, set to UNKNOWN
				results = 0;
			}
			SendMessage(GetDlgItem(hwndDlg, IDC_COMBO2), CB_SETCURSEL, results, 0);
			// US Zip
			// -1 on error
			results = getUSZip();
			if((results < 0) || (results > 99999)) {
				// On error, set to 00000
				results = 0;
			}
			itoa(results, zip, 10);
			SendMessage(GetDlgItem(hwndDlg, IDC_EDIT1), EM_REPLACESEL, TRUE, (LPARAM)zip);
			// Interface
			devname = getInterface();
			tempdev = get_interface_list(&interr, errorbuf);
			devhead = tempdev;
			devcount = 0;
			while(tempdev != NULL) {
				if(devname) {
					if(tempdev->name != NULL) {
						if(!stricmp(tempdev->name, devname)) {
							break;
						}
					}
					if(tempdev->description != NULL) {
						if(!stricmp(tempdev->description, devname)) {
							break;
						}
					}
				}
				tempdev = tempdev->next;
				devcount++;
			}
			if(tempdev != NULL) {
				SendMessage(GetDlgItem(hwndDlg, IDC_COMBO3), CB_SETCURSEL, devcount, 0);
			}
			else {
				SendMessage(GetDlgItem(hwndDlg, IDC_COMBO3), CB_SETCURSEL, 0, 0);
			}
			free_interface_list(devhead);
			// Email
			if((tempemail = getEmail()) != NULL) {
				SendMessage(GetDlgItem(hwndDlg, IDC_EDIT2), EM_REPLACESEL, TRUE, (LPARAM)tempemail);
				free(tempemail);
			}
			break;
		case WM_COMMAND: 
			switch (LOWORD(wParam)) { 
				// Lowest Privacy
				case IDC_RADIO3:
					break;
				// Medium Privacy
				case IDC_RADIO4:
					break;
				// Highest Privacy
				case IDC_RADIO5:
					break;
				// Logfile Size
				case IDC_COMBO1:
					break;
				case IDOK: 
					// Set new properties in properties file
					// Maximum Logfile Size
					results = (int)SendMessage(GetDlgItem(hwndDlg, IDC_COMBO1), CB_GETCURSEL, 0, 0);
					// Geographical Location
					results2 = (int)SendMessage(GetDlgItem(hwndDlg, IDC_COMBO2), CB_GETCURSEL, 0, 0);
					// US Zip
					results3 = (int)SendMessage(GetDlgItem(hwndDlg, IDC_EDIT1), EM_LINELENGTH, 0, 0);
					if(results3 < 7) {
						*((LPWORD)zip) = 9;
						SendMessage(GetDlgItem(hwndDlg, IDC_EDIT1), EM_GETLINE, 0, (LPARAM)zip);
						zip[results3] = '\0';
					}
					else {
						zip[0] = '\0';
					}
					// Interface
					results3 = (int)SendMessage(GetDlgItem(hwndDlg, IDC_COMBO3), CB_GETCURSEL, 0, 0);
					// Email
					results4 = (int)SendMessage(GetDlgItem(hwndDlg, IDC_EDIT2), EM_LINELENGTH, 0, 0);
					if(results4 < 256) {
						*((LPWORD)email) = 255;
						SendMessage(GetDlgItem(hwndDlg, IDC_EDIT2), EM_GETLINE, 0, (LPARAM)email);
						email[results4] = '\0';
					}
					else {
						email[0] = '\0';
					}
					// Privacy Setting
					if(IsDlgButtonChecked(hwndDlg, IDC_RADIO3) == BST_CHECKED) {
						setProperties(0, results, results2, results3, zip, email);
					}
					else if(IsDlgButtonChecked(hwndDlg, IDC_RADIO4) == BST_CHECKED) {
						setProperties(1, results, results2, results3, zip, email);
					}
					else if(IsDlgButtonChecked(hwndDlg, IDC_RADIO5) == BST_CHECKED) {
						setProperties(2, results, results2, results3, zip, email);
					}
					else {
						setProperties(1, results, results2, results3, zip, email);
					}
					// set the Properties Event
					if(HProperties != NULL) {
						SetEvent(HProperties);
					}
					// fall through
				case IDCANCEL:
					EndDialog(hwndDlg, wParam); 
					return TRUE; 
			} 
	}
	return FALSE; 
}

BOOL WINAPI InitLogfileComboBox(HWND hwndCombo) {
	SendMessage(hwndCombo, CB_RESETCONTENT, 0, 0);
	SendMessage(hwndCombo, CB_ADDSTRING, 0, (LPARAM)"1 KByte");
	SendMessage(hwndCombo, CB_ADDSTRING, 0, (LPARAM)"10 KByte");
	SendMessage(hwndCombo, CB_ADDSTRING, 0, (LPARAM)"100 KByte");
	SendMessage(hwndCombo, CB_ADDSTRING, 0, (LPARAM)"1 MByte");
	SendMessage(hwndCombo, CB_ADDSTRING, 0, (LPARAM)"10 MByte");

	return TRUE;
}

BOOL WINAPI InitGeolocationComboBox(HWND hwndCombo) {
	SendMessage(hwndCombo, CB_RESETCONTENT, 0, 0);
	for(int i = 0; i < GEOLOCATIONSIZE; i++) {
		SendMessage(hwndCombo, CB_ADDSTRING, 0, (LPARAM)geolocations[i]);
	}

	return TRUE;
}

BOOL WINAPI InitInterfaceComboBox(HWND hwndCombo) {
	if_info_t *tempdev = NULL;
	if_info_t *devhead = NULL;
	char errorbuf[PCAP_ERRBUF_SIZE];
	int interr;

	SendMessage(hwndCombo, CB_RESETCONTENT, 0, 0);
	tempdev = get_interface_list(&interr, errorbuf);
	devhead = tempdev;
	while(tempdev != NULL) {
		if(tempdev->description != NULL) {
			SendMessage(hwndCombo, CB_ADDSTRING, 0, (LPARAM)tempdev->description);
		}
		else if(tempdev->name != NULL) {
			SendMessage(hwndCombo, CB_ADDSTRING, 0, (LPARAM)tempdev->name);
		}
		tempdev = tempdev->next;
	}
	free_interface_list(devhead);
	return TRUE;
}

// This function retrieves the privacy setting from the conf file
// Returns:
// 0 == LOW privacy (collect everything)
// 1 == MEDIUM privacy (only collect the network portion of the local and remote IP)
// 2 == HIGH privacy (collect no IPs)
// -1 == ERROR (use MEDIUM privacy -- default)
int getPrivacy() {
	char text[100];
	char *collector;
	FILE *fpt;

	if((fpt = fopen(filename, "r")) == NULL) {
		::MessageBox(NULL, "Could Not Open Properties File", "Error", MB_OK);
		exit(1);
	}

	memset(text, '\0', 100);

	while(fgets(text, 100, fpt) != NULL) {
		collector = strtok(text, " \t=");
		if(collector != NULL) {
			if(!strnicmp(collector, "PRIVACY", 8)) {
				collector = strtok(NULL, " \t=");
				if(collector != NULL) {
					if(!strnicmp(collector, "LOW", 3)) {
						fclose(fpt);
						return 0;
					}
					else if(!strnicmp(collector, "MEDIUM", 6)) {
						fclose(fpt);
						return 1;
					}
					else if(!strnicmp(collector, "HIGH", 4)) {
						fclose(fpt);
						return 2;
					}
					else {
						fclose(fpt);
						return -1;
					}
				}
			}
		}
	}
	fclose(fpt);
	return -1;
}

// This function retrieves the logfile size from the conf file
// Returns:
// logfile size
int getLogfileSize() {
	char text[100];
	char *collector;
	FILE *fpt;

	if((fpt = fopen(filename, "r")) == NULL) {
		::MessageBox(NULL, "Could Not Open Properties File", "Error", MB_OK);
		exit(1);
	}

	memset(text, '\0', 100);

	while(fgets(text, 100, fpt) != NULL) {
		collector = strtok(text, " \t=");
		if(collector != NULL) {
			if(!strnicmp(collector, "LOGFILESIZE", 11)) {
				collector = strtok(NULL, " \t=");
				if(collector != NULL) {
					fclose(fpt);
					return atoi(collector);
				}
			}
		}
	}
	fclose(fpt);
	return 0;
}

// This function retrieves the interface name from the conf file
// Returns:
// interface name
char * getInterface() {
	char text[100];
	char *collector;
	char *toBeReturned = NULL;
	FILE *fpt;

	if((fpt = fopen(filename, "r")) == NULL) {
		::MessageBox(NULL, "Could Not Open Properties File", "Error", MB_OK);
		exit(1);
	}

	memset(text, '\0', 100);
	while(fgets(text, 100, fpt) != NULL) {
		collector = strtok(text, " \t=");
		if(collector != NULL) {
			if(!strnicmp(collector, "INTERFACE", 9)) {
				collector = strtok(NULL, "=\"\r\n");
				while(collector != NULL) {
					if(!isspace(collector[0])) {
						if((toBeReturned = (char *)malloc(strlen(collector) + 1)) == NULL) {
							return NULL;
						}
						memset(toBeReturned, '\0', strlen(collector) + 1);
						strncpy(toBeReturned, collector, strlen(collector) + 1);
						fclose(fpt);
						return toBeReturned;
					}
					else {
						collector = strtok(NULL, "=\"\r\n");
					}
				}
			}
		}
	}
	fclose(fpt);
	return NULL;
}

// This function retrieves the geolocation from the conf file
// Returns:
// geographical location or -1 on Error
int getGeolocation() {
	char text[100];
	char *collector;
	FILE *fpt;

	if((fpt = fopen(filename, "r")) == NULL) {
		::MessageBox(NULL, "Could Not Open Properties File", "Error", MB_OK);
		exit(1);
	}

	memset(text, '\0', 100);
	while(fgets(text, 100, fpt) != NULL) {
		collector = strtok(text, " \t=");
		if(collector != NULL) {
			if(!strnicmp(collector, "LOCATION", 8)) {
				collector = strtok(NULL, " \t=");
				if(collector != NULL) {
					fclose(fpt);
					return atoi(collector);
				}
			}
		}
	}
	fclose(fpt);
	return -1;
}

// This function retrieves the US Zip Code from the conf file
// Returns:
// US Zip Code or -1 on Error
int getUSZip() {
	char text[100];
	char *collector;
	FILE *fpt;

	if((fpt = fopen(filename, "r")) == NULL) {
		::MessageBox(NULL, "Could Not Open Properties File", "Error", MB_OK);
		exit(1);
	}

	memset(text, '\0', 100);
	while(fgets(text, 100, fpt) != NULL) {
		collector = strtok(text, " \t=");
		if(collector != NULL) {
			if(!strnicmp(collector, "USZIP", 5)) {
				collector = strtok(NULL, " \t=");
				if(collector != NULL) {
					fclose(fpt);
					return atoi(collector);
				}
			}
		}
	}
	fclose(fpt);
	return -1;
}

// This function retrieves the unique identifier from the conf file
// Returns:
// 32-bit unique identifier
int getIdentifier() {
	char text[100];
	char *collector;
	FILE *fpt;

	if((fpt = fopen(filename, "r")) == NULL) {
		::MessageBox(NULL, "Could Not Open Properties File", "Error", MB_OK);
		exit(1);
	}

	memset(text, '\0', 100);
	while(fgets(text, 100, fpt) != NULL) {
		collector = strtok(text, " \t=");
		if(collector != NULL) {
			if(!strnicmp(collector, "IDENTIFIER", 10)) {
				collector = strtok(NULL, " \t=");
				if(collector != NULL) {
					fclose(fpt);
					return atoi(collector);
				}
			}
		}
	}
	fclose(fpt);
	return -1;
}

// This function retrieves the email address from the conf file
// Returns:
// email address
char * getEmail() {
	char text[256];
	char *collector;
	char *toBeReturned = NULL;
	FILE *fpt;

	if((fpt = fopen(filename, "r")) == NULL) {
		::MessageBox(NULL, "Could Not Open Properties File", "Error", MB_OK);
		exit(1);
	}

	memset(text, '\0', 256);
	while(fgets(text, 256, fpt) != NULL) {
		collector = strtok(text, " \t=");
		if(collector != NULL) {
			if(!strnicmp(collector, "EMAIL", 5)) {
				collector = strtok(NULL, " \t=\r\n");
				if(collector != NULL) {
					if((toBeReturned = (char *)malloc(strlen(collector) + 1)) == NULL) {
						return NULL;
					}
					memset(toBeReturned, '\0', strlen(collector) + 1);
					strncpy(toBeReturned, collector, strlen(collector) + 1);
					fclose(fpt);
					return toBeReturned;
				}
			}
		}
	}
	fclose(fpt);
	return NULL;
}

// Function to Obtain the latest NETI@home version
int getLatestVersion() {
	int rc;
	char buf[4096];
	int bufsize = 4096;
	SOCKET sockfd;
	SOCKADDR_IN server_addr;
	struct hostent *he = NULL;

	sockfd = socket(AF_INET, SOCK_STREAM, 0);
	if(sockfd == INVALID_SOCKET) {
		return -1;
	}

	server_addr.sin_family = AF_INET;
	server_addr.sin_port = htons(UPDATEALERT_PORT);

	// Get IP for DEST_ADDR
	he = gethostbyname(DEST_ADDR);
	if(he != NULL) {
		memcpy((char *)&server_addr.sin_addr.S_un.S_addr, he->h_addr_list[0], he->h_length);
	}
	else {
		closesocket(sockfd);
		return -1;
	}
	memset(&(server_addr.sin_zero), '\0', 8);

	rc = connect(sockfd, (struct sockaddr *)&server_addr, sizeof(server_addr));
	if(rc == SOCKET_ERROR) {
		closesocket(sockfd);
		return -1;
	}

	rc = recv(sockfd, buf, bufsize, 0);

	while(rc > 0) {
		if(rc == SOCKET_ERROR) {
			closesocket(sockfd);
			return -1;
		}

		bufsize -= rc;

		rc = recv(sockfd, buf + ((4096 - bufsize) * sizeof(char)), bufsize, 0);
	}

	closesocket(sockfd);
	
	if(rc < 0) {
		return -1;
	}

	if(buf == NULL) {
		return -1;
	}

	return atoi(buf);
}

// Set the privacy level in the configuration file
// privacylevel is the level to set at:
// 0 == LOW
// 1 == MEDIUM
// 2 == HIGH
// anything else == MEDIUM
// returns 0 on success, -1 otherwise
// Set the size of the logfile in the configuration file
// logsize is the level to set at:
// 0 == 1 KByte
// 1 == 10 KBytes
// 2 == 100 KBytes
// 3 == 1 MByte
// 4 == 10 MByte
// anything else == 1 MByte
// returns 0 on success, -1 otherwise
int setProperties(int privacylevel, int logsize, int geolocation, int intrfc, char *zip, char *email) {
	FILE *fpt;
	if_info_t *tempdev = NULL;
	if_info_t *devhead = NULL;
	int devcount = 0;
	int interr;
	int tempidentifier = -1;
	char errorbuf[PCAP_ERRBUF_SIZE];

	// First, read in identifier
	tempidentifier = getIdentifier();

	// Destroy the old file and create a new one - could probably be cleaner
	if((fpt = fopen(filename, "w")) == NULL) {
		::MessageBox(NULL, "Could Not Open Properties File", "Error", MB_OK);
		exit(1);
	}

	// Privacy Setting
	fprintf(fpt, "# Privacy setting can be LOW, MEDIUM, or HIGH\n");
	fprintf(fpt, "#\n");
	fprintf(fpt, "# LOW privacy will cause NETI@home to collect\n");
	fprintf(fpt, "#     and report the full local, remote, and multicast IP addresses\n");
	fprintf(fpt, "# MEDIUM (default) privacy will cause NETI@home to report only the\n");
	fprintf(fpt, "#     network portion of the local, remote, and multicast IP addresses\n");
	fprintf(fpt, "# HIGH privacy will cause NETI@home to not report any IP addresses\n");
	if(privacylevel == 0) {
		fprintf(fpt, "PRIVACY = LOW\n");
	}
	else if(privacylevel == 2) {
		fprintf(fpt, "PRIVACY = HIGH\n");
	}
	else {
		fprintf(fpt, "PRIVACY = MEDIUM\n");
	}
	fprintf(fpt, "\n");

	// Maximum Logfile Size
	fprintf(fpt, "# Maximum Log File Size (in Bytes)\n");
	if(logsize == 0) {
		fprintf(fpt, "LOGFILESIZE = 1000\n");
	}
	else if(logsize == 1) {
		fprintf(fpt, "LOGFILESIZE = 10000\n");
	}
	else if(logsize == 2) {
		fprintf(fpt, "LOGFILESIZE = 100000\n");
	}
	else if(logsize == 4) {
		fprintf(fpt, "LOGFILESIZE = 10000000\n");
	}
	else {
		fprintf(fpt, "LOGFILESIZE = 1000000\n");
	}
	fprintf(fpt, "\n");

	// Interface
	fprintf(fpt, "# The interface that you would like NETI@home to monitor.\n");
	fprintf(fpt, "#     You may also specify the interface on the command line,\n");
	fprintf(fpt, "#     or if no interface is specified on the command line\n");
	fprintf(fpt, "#     or here in the configuration file,\n");
	fprintf(fpt, "#     then the default interface is selected.\n");
	tempdev = get_interface_list(&interr, errorbuf);
	devhead = tempdev;
	devcount = 0;
	while(tempdev != NULL) {
		if(devcount == intrfc) {
			if(tempdev->description != NULL) {
				fprintf(fpt, "INTERFACE = \"%s\"", tempdev->description);
			}
			else if(tempdev->name != NULL) {
				fprintf(fpt, "INTERFACE = \"%s\"", tempdev->name);
			}
			break;
		}
		tempdev = tempdev->next;
		devcount++;
	}
	fprintf(fpt, "\n");
	free_interface_list(devhead);

	// Geolocation
	fprintf(fpt, "# The geographical location where you are located.\n");
	fprintf(fpt, "#     Location is a number from 0 to 262 and these numbers\n");
	fprintf(fpt, "#     are defined in the locations.h file.\n");
	fprintf(fpt, "LOCATION = %d\n", geolocation);
	fprintf(fpt, "\n");

	// US Zip
	fprintf(fpt, "# If you are located in the United States, please specify your\n");
	fprintf(fpt, "#     US Zip code.\n");
	fprintf(fpt, "USZIP = %s\n", zip);
	fprintf(fpt, "\n");

	// Email
	fprintf(fpt, "# If you wish to receive a minimal amount of emails updating\n");
	fprintf(fpt, "#     you on NETI@home, please enter your email address below.\n");
	fprintf(fpt, "#     NOTE: Your email address will not be associated with the\n");
	fprintf(fpt, "#     data collected.\n");
	fprintf(fpt, "EMAIL = %s\n", email);

	// Identifier
	if(tempidentifier > 0) {
		fprintf(fpt, "# This is the unique identifier.\n");
		fprintf(fpt, "#     Please do not change as it will only harm research efforts.\n");
		fprintf(fpt, "IDENTIFIER = %u\n", tempidentifier);
	}

	fclose(fpt);
	return 0;
}

// The following code was taken from Ethereal 0.10.4, with minor modification
if_info_t * if_info_new(char *name, char *description)
{
	if_info_t *if_info;

	if((if_info = (if_info_t *)malloc(sizeof (if_info_t))) == NULL) {
		return NULL;
	}
	if_info->name = strdup(name);
	if (description == NULL) {
		if_info->description = NULL;
	}
	else {
		if_info->description = strdup(description);
	}
	if_info->addrs = NULL;
	if_info->next = NULL;

	return if_info;
}

/*
 * This will use "pcap_findalldevs()" if we have it, otherwise it'll
 * fail.
 */
if_info_t * get_interface_list(int *err, char *err_str)
{
	return get_interface_list_findalldevs(err, err_str);
}

if_info_t * get_interface_list_findalldevs(int *err, char *err_str)
{
	if_info_t *il = NULL;
	if_info_t *count = NULL;
	pcap_if_t *alldevs, *dev;
	pcap_addr_t *addr;
	if_info_t *if_info;
	if_addr_t *if_addr = NULL;

	if (pcap_findalldevs(&alldevs, err_str) == -1) {
		*err = CANT_GET_INTERFACE_LIST;
		return NULL;
	}

	if (alldevs == NULL) {
		/*
		 * No interfaces found.
		 */
		*err = NO_INTERFACES_FOUND;
		return NULL;
	}

	for (dev = alldevs; dev != NULL; dev = dev->next) {
		if_info = if_info_new(dev->name, dev->description);
		for(addr = dev->addresses; addr != NULL; addr = addr->next) {
			if(addr->addr->sa_family == AF_INET) {
				if_addr = if_info->addrs;
				if(if_addr == NULL) {
					if_info->addrs = (if_addr_t *)malloc(sizeof(if_addr_t));
					if_addr = if_info->addrs;
				}
				else {
					while(if_addr->next != NULL) {
						if_addr = if_addr->next;
					}
					if_addr->next = (if_addr_t *)malloc(sizeof(if_addr_t));
					if_addr = if_addr->next;
				}
				memcpy((struct in_addr *)&if_addr->ip, (struct in_addr *)&((struct sockaddr_in *)addr->addr)->sin_addr, sizeof(struct in_addr));
				if(addr->netmask != NULL) {
					memcpy((struct in_addr *)&if_addr->netmask, (struct in_addr *)&((struct sockaddr_in *)addr->netmask)->sin_addr, sizeof(struct in_addr));
				}
				if_addr->next = NULL;
			}
		}
		if(il == NULL) {
			il = if_info;
		}
		else {
			for(count = il; count != NULL; count = count->next) {
				if(count->next == NULL) {
					count->next = if_info;
					break;
				}
			}
		}
	}
	pcap_freealldevs(alldevs);

	return il;
}

void free_interface_list(if_info_t *if_list)
{
	if_info_t *dev = NULL;
	if_info_t *prevdev = NULL;
	if_addr_t *addrs = NULL;
	if_addr_t *prevaddrs = NULL;

	dev = if_list;
	while(dev != NULL) {
		if(dev->name != NULL) {
			free(dev->name);
		}
		if(dev->description != NULL) {
			free(dev->description);
		}
		addrs = dev->addrs;
		while(addrs != NULL) {
			prevaddrs = addrs;
			addrs = addrs->next;
			free(prevaddrs);
		}
		prevdev = dev;
		dev = dev->next;
		free(prevdev);
	}
}

/****************************************************************************
 *
 * Function: init_winsock(void)
 *
 * Purpose:  Initialize winsock.
 *
 * Arguments: None.
 *
 * Returns: 0 => Initilization failed.
 *          1 => Initilization succeeded.
 *
 ****************************************************************************/

int init_winsock(void)
{
    WORD wVersionRequested = MAKEWORD(1, 1);
    WSADATA wsaData;

    if (WSAStartup(wVersionRequested, &wsaData))
    {
        return 0;
    }

    if (LOBYTE(wsaData.wVersion) < 1 || HIBYTE(wsaData.wVersion) < 1)
    {
        WSACleanup();
        return 0;
    }

    return 1;
}
