/* Copyright 2003-2005 Charles Robert Simpson, Jr.
 *
 * This file is part of NETI@home.
 * 
 * NETI@home is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * NETI@home is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with NETI@home; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


// Program to parse out pertinent data from output file logfile

#include "netistats.h"

#ifndef WIN32
#define LOGFILE "/var/log/netilog"
#endif

int main(int argc, char *argv[]) {
	FILE *fpt = NULL;
	char *msg = NULL;
	char *orig = NULL;
	int32_t *type = NULL;
	int32_t *ver = NULL;
	int32_t version;
	struct Neti_Header *netihead = NULL;
	struct Neti_Header_v2 *netihead_v2 = NULL;
	struct TCP_Stats *tcpstats = NULL;
	struct TCP_Stats_v2 *tcpstats_v2 = NULL;
	struct UDP_Stats *udpstats = NULL;
	struct UDP_Stats_v2 *udpstats_v2 = NULL;
	struct ICMP_Stats *icmpstats = NULL;
	struct ICMP_Stats_v2 *icmpstats_v2 = NULL;
	struct IGMP_Stats *igmpstats = NULL;
	struct IGMP_Stats_v2 *igmpstats_v2 = NULL;
	int parseerrs;
	time_t temptime;
	int filecount = 0;
#ifdef WIN32
	HKEY hKey;
	LONG lRet;
	char logfilename[80];
	DWORD dwBufLen = 80;
#endif

	parseerrs = 0;

	if((msg = (char *)malloc(sizeof(struct TCP_Stats_v2))) == NULL) {
		printf("NETI@home Error: Cannot malloc for logparse (Lack of Memory?)\n");
		exit(1);
	}
	orig = msg;

	filecount = argc - 1;

	do {

		if(argc < 2) {
#ifdef WIN32
			if(RegOpenKeyEx(HKEY_LOCAL_MACHINE, TEXT("Software\\NETI@home"), 0, KEY_QUERY_VALUE, &hKey) != ERROR_SUCCESS) {
				printf("Error accessing system registry\n");
				free(msg);
				return -1;
			}
			lRet = RegQueryValueEx(hKey, TEXT(""), NULL, NULL, (LPBYTE)logfilename, &dwBufLen);
			RegCloseKey(hKey);
			if(lRet != ERROR_SUCCESS) {
				printf("Error reading system registry\n");
				free(msg);
				return -1;
			}
			// Append "\\netilog" to logfilename
			logfilename[dwBufLen] = '\0';
			strncat(logfilename, "\\netilog", 9);

			if((fpt = fopen(logfilename, "rb")) == NULL) {
				printf("NETI@home Error: Cannot open logfile\n");
				printf("If you have recently started using NETI@home\n");
				printf("the log file may not have been created yet.\n");
				printf("The log file is created the first time you\n");
				printf("send data to the NETI@home server.\n");
				printf("This is done so that the log file contains\n");
				printf("the exact same data sent to the NETI@home server.\n");
				printf("If this error persists or for more information\n");
				printf("please visit http://www.neti.gatech.edu\n");
				free(msg);
				return -1;
			}
#else
			if((fpt = fopen(LOGFILE, "rb")) == NULL) {
				printf("NETI@home Error: Cannot open logfile\n");
				printf("If you have recently started using NETI@home\n");
				printf("the log file may not have been created yet.\n");
				printf("The log file is created the first time you\n");
				printf("send data to the NETI@home server.\n");
				printf("This is done so that the log file contains\n");
				printf("the exact same data sent to the NETI@home server.\n");
				printf("If this error persists or for more information\n");
				printf("please visit http://www.neti.gatech.edu\n");
				free(msg);
				return -1;
			}
#endif
		}
		else {
			if((fpt = fopen(argv[argc - filecount], "rb")) == NULL) {
				printf("NETI@home Error: Cannot open the specified file: %s\n", argv[argc - filecount]);
				free(msg);
				return -1;
			}

			printf("Reading File: %s\n", argv[argc - filecount]);
		}

		fread(msg, 1, sizeof(int32_t), fpt);
		while(!feof(fpt)) {
			type = (int32_t *)msg;
			if((ntohl(*type) == NETI_NEW_USER) || (ntohl(*type) == NETI_NEW_USER2)) {
				printf("======================================================================\n");
				printf("======================================================================\n");
				printf("NEW USER\n");
				msg += sizeof(int32_t);
				fread(msg, sizeof(int32_t), 2, fpt);
				msg += sizeof(int32_t);
				ver = (int32_t *)msg;
				version = ntohl(*ver);
				netihead = NULL;
				netihead_v2 = NULL;
				if(version < 19) {
					// Version 1
					msg += sizeof(int32_t);
					fread(msg, 1, sizeof(struct Neti_Header) - (2 * sizeof(int32_t)), fpt);
					msg -= (2 * sizeof(int32_t));
					netihead = (struct Neti_Header *)msg;
					printf("Neti Version == %d\n", ntohl(netihead->netiversion));
					temptime = ntohl(netihead->sendtime);
					printf("Send Time == %s", ctime(&temptime));
					printf("OS Type == %s\n", netihead->ostype);
				}
				else {
					// Version 2
					msg += sizeof(int32_t);
					fread(msg, 1, sizeof(struct Neti_Header_v2) - (2 * sizeof(int32_t)), fpt);
					msg -= (2 * sizeof(int32_t));
					netihead_v2 = (struct Neti_Header_v2 *)msg;
					printf("Neti Version == %d\n", ntohl(netihead_v2->netiversion));
					temptime = ntohl(netihead_v2->starttime);
					printf("Start Time == %s", ctime(&temptime));
					temptime = ntohl(netihead_v2->sendtime);
					printf("Send Time == %s", ctime(&temptime));
					printf("Identifier == %u\n", ntohl(netihead_v2->identifier));
					printf("Privacy Level == %hu\n", ntohs(netihead_v2->privacylevel));
					printf("Geolocation == %hu\n", ntohs(netihead_v2->geolocation));
					printf("US Zip == %u\n", ntohl(netihead_v2->uszip));
					printf("Datalink Type == %d\n", ntohl(netihead_v2->datalink));
					printf("Total Packets == %u\n", ntohl(netihead_v2->totalpkts));
					printf("Discarded Packets == %u\n", ntohl(netihead_v2->discpkts));
					printf("Dropped Packets == %u\n", ntohl(netihead_v2->droppkts));
					printf("TCP Packets == %u\n", ntohl(netihead_v2->tcppkts));
					printf("UDP Packets == %u\n", ntohl(netihead_v2->udppkts));
					printf("ICMP Packets == %u\n", ntohl(netihead_v2->icmppkts));
					printf("IGMP Packets == %u\n", ntohl(netihead_v2->igmppkts));
					printf("IPv6 Packets == %u\n", ntohl(netihead_v2->ipv6pkts));
					printf("Fragmented Packets == %u\n", ntohl(netihead_v2->fragpkts));
					printf("ARP Packets == %u\n", ntohl(netihead_v2->arppkts));
					printf("IPX Packets == %u\n", ntohl(netihead_v2->ipxpkts));
					printf("EAPOL Packets == %u\n", ntohl(netihead_v2->eapolpkts));
					printf("Other Packets == %u\n", ntohl(netihead_v2->otherpkts));
					printf("Wifi Management Packets == %u\n", ntohl(netihead_v2->wifimgmtpkts));
					printf("Wifi Control Packets == %u\n", ntohl(netihead_v2->wificontpkts));
					printf("Wifi Data Packets == %u\n", ntohl(netihead_v2->wifidatapkts));
					printf("OS Type == %s\n", netihead_v2->ostype);
				}



				printf("======================================================================\n");
				printf("======================================================================\n");
				printf("======================================================================\n");
				msg = orig;
			}
			else if(ntohl(*type) == NETI_TCP_FLOW) {
				printf("TCP Flow\n");
				tcpstats = NULL;
				tcpstats_v2 = NULL;
				if(version < 19) {
					// Version 1
					tcpstats = (struct TCP_Stats *)msg;
					msg += sizeof(int32_t);
					fread(msg, 1, sizeof(struct TCP_Stats) - sizeof(int32_t), fpt);
					printf("dest_ip == %s\n", inet_ntoa(tcpstats->dest_ip));
					printf("src_ip == %s\n", inet_ntoa(tcpstats->src_ip));
					temptime = ntohl(tcpstats->time_established.tv_sec);
					printf("time_established (using ctime, no usecs) == %s", ctime(&temptime));
					printf("time_established == %u.%06u\n", ntohl(tcpstats->time_established.tv_sec), ntohl(tcpstats->time_established.tv_usec));
					temptime = ntohl(tcpstats->time_closed.tv_sec);
					printf("time_closed (using ctime, no usecs) == %s", ctime(&temptime));
					printf("time_closed == %u.%06u\n", ntohl(tcpstats->time_closed.tv_sec), ntohl(tcpstats->time_closed.tv_usec));
					printf("src_port == %hu\n", ntohs(tcpstats->src_port));
					printf("dest_port == %hu\n", ntohs(tcpstats->dest_port));
					printf("num_badsum == %d\n", ntohl(tcpstats->num_badsum));
					printf("num_badipsum == %d\n", ntohl(tcpstats->num_badipsum));
					printf("packets_sent == %d\n", ntohl(tcpstats->packets_sent));
					printf("packets_received == %d\n", ntohl(tcpstats->packets_received));
					printf("bytes_sent == %d\n", ntohl(tcpstats->bytes_sent));
					printf("bytes_received == %d\n", ntohl(tcpstats->bytes_received));
					printf("num_acks == %d\n", ntohl(tcpstats->num_acks));
					printf("num_dup_acks == %d\n", ntohl(tcpstats->num_dup_acks));
					printf("num_trip_acks == %d\n", ntohl(tcpstats->num_trip_acks));
					printf("num_urg == %d\n", ntohl(tcpstats->num_urg));
					printf("num_push == %d\n", ntohl(tcpstats->num_push));
					printf("num_ecnecho == %d\n", ntohl(tcpstats->num_ecnecho));
					printf("num_cwr == %d\n", ntohl(tcpstats->num_cwr));
					printf("sender_SACK_perm == %d\n", ntohl(tcpstats->sender_SACK_perm));
					printf("receiver_SACK_perm == %d\n", ntohl(tcpstats->receiver_SACK_perm));
					printf("num_frag == %d\n", ntohl(tcpstats->num_frag));
					printf("num_dontfrag == %d\n", ntohl(tcpstats->num_dontfrag));
					printf("sender_max_win == %d\n", ntohl(tcpstats->sender_max_win));
					printf("sender_ave_win == %d\n", ntohl(tcpstats->sender_ave_win));
					printf("sender_min_win == %d\n", ntohl(tcpstats->sender_min_win));
					printf("receiver_max_win == %d\n", ntohl(tcpstats->receiver_max_win));
					printf("receiver_ave_win == %d\n", ntohl(tcpstats->receiver_ave_win));
					printf("receiver_min_win == %d\n", ntohl(tcpstats->receiver_min_win));
					printf("sender_min_ttl == %d\n", ntohl(tcpstats->sender_min_ttl));
					printf("sender_max_ttl == %d\n", ntohl(tcpstats->sender_max_ttl));
					printf("receiver_min_ttl == %d\n", ntohl(tcpstats->receiver_min_ttl));
					printf("receiver_max_ttl == %d\n", ntohl(tcpstats->receiver_max_ttl));
					printf("num_retrans == %d\n", ntohl(tcpstats->num_retrans));
					printf("bytes_retrans == %d\n", ntohl(tcpstats->bytes_retrans));
					printf("num_timeouts == %d\n", ntohl(tcpstats->num_timeouts));
					//printf("num_ss == %d\n", tcpstats->num_ss);
					//printf("num_cwnd_reduc == %d\n", tcpstats->num_cwnd_reduc);
					//printf("num_cwnd_inc == %d\n", tcpstats->num_cwnd_inc);
					printf("min_rtt == %u.%06u\n", ntohl(tcpstats->min_rtt.tv_sec), ntohl(tcpstats->min_rtt.tv_usec));
					printf("max_rtt == %u.%06u\n", ntohl(tcpstats->max_rtt.tv_sec), ntohl(tcpstats->max_rtt.tv_usec));
					printf("ave_rtt == %u.%06u\n", ntohl(tcpstats->ave_rtt.tv_sec), ntohl(tcpstats->ave_rtt.tv_usec));
					printf("idle_close == %d\n", ntohl(tcpstats->idle_close));
					if(ntohl(tcpstats->rst_close) == NETI_SENDER) {
						printf("rst_close == Sender\n");
					}
					else if(ntohl(tcpstats->rst_close) == NETI_RECEIVER) {
						printf("rst_close == Receiver\n");
					}
					else {
						printf("rst_close == %d\n", ntohl(tcpstats->rst_close));
					}
					printf("num_in_order == %d\n", ntohl(tcpstats->num_in_order));
					printf("num_out_order == %d\n", ntohl(tcpstats->num_out_order));
					//printf("small_interarrival == %u.%06u\n", tcpstats->small_interarrival.tv_sec, tcpstats->small_interarrival.tv_usec);
					//printf("largest_interarrival == %u.%06u\n", tcpstats->largest_interarrival.tv_sec, tcpstats->largest_interarrival.tv_usec);
					printf("sender_mss == %d\n", ntohl(tcpstats->sender_mss));
					printf("receiver_mss == %d\n", ntohl(tcpstats->receiver_mss));
				}
				else {
					// Version 2
					tcpstats_v2 = (struct TCP_Stats_v2 *)msg;
					msg += sizeof(int32_t);
					fread(msg, 1, sizeof(struct TCP_Stats_v2) - sizeof(int32_t), fpt);
					printf("remote_ip == %s\n", inet_ntoa(tcpstats_v2->remote_ip));
					printf("local_ip == %s\n", inet_ntoa(tcpstats_v2->local_ip));
					printf("local_netmask == %s\n", inet_ntoa(tcpstats_v2->local_netmask));
					temptime = ntohl(tcpstats_v2->time_established.tv_sec);
					printf("time_established (using ctime, no usecs) == %s", ctime(&temptime));
					printf("time_established == %u.%06u\n", ntohl(tcpstats_v2->time_established.tv_sec), ntohl(tcpstats_v2->time_established.tv_usec));
					temptime = ntohl(tcpstats_v2->time_closed.tv_sec);
					printf("time_closed (using ctime, no usecs) == %s", ctime(&temptime));
					printf("time_closed == %u.%06u\n", ntohl(tcpstats_v2->time_closed.tv_sec), ntohl(tcpstats_v2->time_closed.tv_usec));
					printf("local_port == %hu\n", ntohs(tcpstats_v2->local_port));
					printf("remote_port == %hu\n", ntohs(tcpstats_v2->remote_port));
					printf("num_notcpsum == %u\n", ntohl(tcpstats_v2->num_notcpsum));
					printf("num_badtcpsum == %u\n", ntohl(tcpstats_v2->num_badtcpsum));
					printf("num_badipsum == %u\n", ntohl(tcpstats_v2->num_badipsum));
					printf("packets_sent == %u\n", ntohl(tcpstats_v2->packets_sent));
					printf("packets_received == %u\n", ntohl(tcpstats_v2->packets_received));
					printf("bytes_sent == %u\n", ntohl(tcpstats_v2->bytes_sent));
					printf("bytes_received == %u\n", ntohl(tcpstats_v2->bytes_received));
					printf("num_acks_sent == %u\n", ntohl(tcpstats_v2->num_acks_sent));
					printf("num_acks_received == %u\n", ntohl(tcpstats_v2->num_acks_received));
					printf("num_dup_acks_sent == %u\n", ntohl(tcpstats_v2->num_dup_acks_sent));
					printf("num_dup_acks_received == %u\n", ntohl(tcpstats_v2->num_dup_acks_received));
					printf("num_doub_acks_sent == %u\n", ntohl(tcpstats_v2->num_doub_acks_sent));
					printf("num_doub_acks_received == %u\n", ntohl(tcpstats_v2->num_doub_acks_received));
					printf("num_trip_acks_sent == %u\n", ntohl(tcpstats_v2->num_trip_acks_sent));
					printf("num_trip_acks_received == %u\n", ntohl(tcpstats_v2->num_trip_acks_received));
					printf("num_past_trip_dup_sent == %u\n", ntohl(tcpstats_v2->num_past_trip_dup_sent));
					printf("num_past_trip_dup_received == %u\n", ntohl(tcpstats_v2->num_past_trip_dup_received));
					printf("min_packet_size_sent == %hu\n", ntohs(tcpstats_v2->min_packet_size_sent));
					printf("min_packet_size_received == %hu\n", ntohs(tcpstats_v2->min_packet_size_received));
					printf("ave_packet_size_sent == %hu\n", ntohs(tcpstats_v2->ave_packet_size_sent));
					printf("ave_packet_size_received == %hu\n", ntohs(tcpstats_v2->ave_packet_size_received));
					printf("max_packet_size_sent == %hu\n", ntohs(tcpstats_v2->max_packet_size_sent));
					printf("max_packet_size_received == %hu\n", ntohs(tcpstats_v2->max_packet_size_received));
					printf("num_urg_sent == %u\n", ntohl(tcpstats_v2->num_urg_sent));
					printf("num_urg_received == %u\n", ntohl(tcpstats_v2->num_urg_received));
					printf("num_push_sent == %u\n", ntohl(tcpstats_v2->num_push_sent));
					printf("num_push_received == %u\n", ntohl(tcpstats_v2->num_push_received));
					printf("num_ecnecho_sent == %u\n", ntohl(tcpstats_v2->num_ecnecho_sent));
					printf("num_ecnecho_received == %u\n", ntohl(tcpstats_v2->num_ecnecho_received));
					printf("num_cwr_sent == %u\n", ntohl(tcpstats_v2->num_cwr_sent));
					printf("num_cwr_received == %u\n", ntohl(tcpstats_v2->num_cwr_received));
					printf("num_frag_sent == %u\n", ntohl(tcpstats_v2->num_frag_sent));
					printf("num_frag_received == %u\n", ntohl(tcpstats_v2->num_frag_received));
					printf("num_dontfrag_sent == %u\n", ntohl(tcpstats_v2->num_dontfrag_sent));
					printf("num_dontfrag_received == %u\n", ntohl(tcpstats_v2->num_dontfrag_received));
					printf("local_min_win == %hu\n", ntohs(tcpstats_v2->local_min_win));
					printf("remote_min_win == %hu\n", ntohs(tcpstats_v2->remote_min_win));
					printf("local_ave_win == %hu\n", ntohs(tcpstats_v2->local_ave_win));
					printf("remote_ave_win == %hu\n", ntohs(tcpstats_v2->remote_ave_win));
					printf("local_max_win == %hu\n", ntohs(tcpstats_v2->local_max_win));
					printf("remote_max_win == %hu\n", ntohs(tcpstats_v2->remote_max_win));
					printf("local_win_scale == %d\n", tcpstats_v2->local_win_scale);
					printf("remote_win_scale == %d\n", tcpstats_v2->remote_win_scale);
					printf("local_min_ttl == %d\n", tcpstats_v2->local_min_ttl);
					printf("local_max_ttl == %d\n", tcpstats_v2->local_max_ttl);
					printf("remote_min_ttl == %d\n", tcpstats_v2->remote_min_ttl);
					printf("remote_max_ttl == %d\n", tcpstats_v2->remote_max_ttl);
					printf("num_retrans_sent == %u\n", ntohl(tcpstats_v2->num_retrans_sent));
					printf("num_retrans_received == %u\n", ntohl(tcpstats_v2->num_retrans_received));
					printf("bytes_retrans_sent == %u\n", ntohl(tcpstats_v2->bytes_retrans_sent));
					printf("bytes_retrans_received == %u\n", ntohl(tcpstats_v2->bytes_retrans_received));
					printf("num_inactivity_periods == %u\n", ntohl(tcpstats_v2->num_inactivity_periods));
					printf("min_rtt == %u.%06u\n", ntohl(tcpstats_v2->min_rtt.tv_sec), ntohl(tcpstats_v2->min_rtt.tv_usec));
					printf("max_rtt == %u.%06u\n", ntohl(tcpstats_v2->max_rtt.tv_sec), ntohl(tcpstats_v2->max_rtt.tv_usec));
					printf("ave_rtt == %u.%06u\n", ntohl(tcpstats_v2->ave_rtt.tv_sec), ntohl(tcpstats_v2->ave_rtt.tv_usec));
					printf("syn_rtt == %u.%06u\n", ntohl(tcpstats_v2->syn_rtt.tv_sec), ntohl(tcpstats_v2->syn_rtt.tv_usec));
					printf("num_in_order == %u\n", ntohl(tcpstats_v2->num_in_order));
					printf("num_out_order == %u\n", ntohl(tcpstats_v2->num_out_order));
					printf("local_mss == %u\n", ntohl(tcpstats_v2->local_mss));
					printf("remote_mss == %u\n", ntohl(tcpstats_v2->remote_mss));
					if(tcpstats_v2->con_estb_method == SYN_SENT) {
						printf("con_estb_method == SYN Sent\n");
					}
					else if(tcpstats_v2->con_estb_method == SYN_RECEIVED) {
						printf("con_estb_method == SYN Received\n");
					}
					else {
						printf("con_estb_method == UNKNOWN\n");
					}
					if(tcpstats_v2->closure_method == FIN_SENT) {
						printf("closure_method == FIN_SENT\n");
					}
					else if(tcpstats_v2->closure_method == FIN_RECEIVED) {
						printf("closure_method == FIN_RECEIVED\n");
					}
					else if(tcpstats_v2->closure_method == RST_SENT) {
						printf("closure_method == RST_SENT\n");
					}
					else if(tcpstats_v2->closure_method == RST_RECEIVED) {
						printf("closure_method == RST_RECEIVED\n");
					}
					else if(tcpstats_v2->closure_method == IDLE_CLOSED) {
						printf("closure_method == IDLE_CLOSED\n");
					}
					else {
						printf("closure_method == UNKNOWN\n");
					}
					printf("local_SACK_perm == %d\n", tcpstats_v2->local_SACK_perm);
					printf("remote_SACK_perm == %d\n", tcpstats_v2->remote_SACK_perm);
				}
				printf("======================================================================\n");
				msg = orig;
			}
			else if(ntohl(*type) == NETI_UDP_FLOW) {
				printf("UDP Flow\n");
				udpstats = NULL;
				udpstats_v2 = NULL;
				if(version < 19) {
					// Version 1
					udpstats = (struct UDP_Stats *)msg;
					msg += sizeof(int32_t);
					fread(msg, 1, sizeof(struct UDP_Stats) - sizeof(int32_t), fpt);
					printf("dest_ip == %s\n", inet_ntoa(udpstats->dest_ip));
					printf("src_ip == %s\n", inet_ntoa(udpstats->src_ip));
					printf("src_port == %hu\n", ntohs(udpstats->src_port));
					printf("dest_port == %hu\n", ntohs(udpstats->dest_port));
					printf("num_badsum == %d\n", ntohl(udpstats->num_badsum));
					printf("num_badipsum == %d\n", ntohl(udpstats->num_badipsum));
					printf("num_packets == %d\n", ntohl(udpstats->num_packets));
					printf("num_frag == %d\n", ntohl(udpstats->num_frag));
					printf("num_dontfrag == %d\n", ntohl(udpstats->num_dontfrag));
					printf("ave_packet_size == %d\n", ntohl(udpstats->ave_packet_size));
					printf("min_packet_size == %d\n", ntohl(udpstats->min_packet_size));
					printf("max_packet_size == %d\n", ntohl(udpstats->max_packet_size));
					temptime = ntohl(udpstats->time_first_packet.tv_sec);
					printf("time_first_packet (using ctime, no usecs) == %s", ctime(&temptime));
					printf("time_first_packet == %u.%06u\n", ntohl(udpstats->time_first_packet.tv_sec), ntohl(udpstats->time_first_packet.tv_usec));
					temptime = ntohl(udpstats->time_last_packet.tv_sec);
					printf("time_last_packet (using ctime, no usecs) == %s", ctime(&temptime));
					printf("time_last_packet == %u.%06u\n", ntohl(udpstats->time_last_packet.tv_sec), ntohl(udpstats->time_last_packet.tv_usec));
				}
				else {
					// Version 2
					udpstats_v2 = (struct UDP_Stats_v2 *)msg;
					msg += sizeof(int32_t);
					fread(msg, 1, sizeof(struct UDP_Stats_v2) - sizeof(int32_t), fpt);
					printf("remote_ip == %s\n", inet_ntoa(udpstats_v2->remote_ip));
					printf("local_ip == %s\n", inet_ntoa(udpstats_v2->local_ip));
					printf("local_netmask == %s\n", inet_ntoa(udpstats_v2->local_netmask));
					printf("local_port == %hu\n", ntohs(udpstats_v2->local_port));
					printf("remote_port == %hu\n", ntohs(udpstats_v2->remote_port));
					printf("num_noudpsum == %u\n", ntohl(udpstats_v2->num_noudpsum));
					printf("num_badudpsum == %u\n", ntohl(udpstats_v2->num_badudpsum));
					printf("num_badipsum == %u\n", ntohl(udpstats_v2->num_badipsum));
					printf("num_packets_sent == %u\n", ntohl(udpstats_v2->num_packets_sent));
					printf("num_packets_received == %u\n", ntohl(udpstats_v2->num_packets_received));
					printf("num_bytes_sent == %u\n", ntohl(udpstats_v2->num_bytes_sent));
					printf("num_bytes_received == %u\n", ntohl(udpstats_v2->num_bytes_received));
					printf("num_frag_sent == %u\n", ntohl(udpstats_v2->num_frag_sent));
					printf("num_frag_received == %u\n", ntohl(udpstats_v2->num_frag_received));
					printf("num_dontfrag_sent == %u\n", ntohl(udpstats_v2->num_dontfrag_sent));
					printf("num_dontfrag_received == %u\n", ntohl(udpstats_v2->num_dontfrag_received));
					printf("local_min_ttl == %d\n", udpstats_v2->local_min_ttl);
					printf("local_max_ttl == %d\n", udpstats_v2->local_max_ttl);
					printf("remote_min_ttl == %d\n", udpstats_v2->remote_min_ttl);
					printf("remote_max_ttl == %d\n", udpstats_v2->remote_max_ttl);
					printf("min_packet_size_sent == %hd\n", ntohs(udpstats_v2->min_packet_size_sent));
					printf("min_packet_size_received == %hd\n", ntohs(udpstats_v2->min_packet_size_received));
					printf("ave_packet_size_sent == %hu\n", ntohs(udpstats_v2->ave_packet_size_sent));
					printf("ave_packet_size_received == %hu\n", ntohs(udpstats_v2->ave_packet_size_received));
					printf("max_packet_size_sent == %hu\n", ntohs(udpstats_v2->max_packet_size_sent));
					printf("max_packet_size_received == %hu\n", ntohs(udpstats_v2->max_packet_size_received));
					temptime = ntohl(udpstats_v2->time_first_packet.tv_sec);
					printf("time_first_packet (using ctime, no usecs) == %s", ctime(&temptime));
					printf("time_first_packet == %u.%06u\n", ntohl(udpstats_v2->time_first_packet.tv_sec), ntohl(udpstats_v2->time_first_packet.tv_usec));
					temptime = ntohl(udpstats_v2->time_last_packet.tv_sec);
					printf("time_last_packet (using ctime, no usecs) == %s", ctime(&temptime));
					printf("time_last_packet == %u.%06u\n", ntohl(udpstats_v2->time_last_packet.tv_sec), ntohl(udpstats_v2->time_last_packet.tv_usec));
				}
				printf("======================================================================\n");
				msg = orig;
			}
			else if(ntohl(*type) == NETI_ICMP_FLOW) {
				printf("ICMP Flow\n");
				icmpstats = NULL;
				icmpstats_v2 = NULL;
				if(version < 19) {
					// Version 1
					icmpstats = (struct ICMP_Stats *)msg;
					msg += sizeof(int32_t);
					fread(msg, 1, sizeof(struct ICMP_Stats) - sizeof(int32_t), fpt);
					printf("dest_ip == %s\n", inet_ntoa(icmpstats->dest_ip));
					printf("src_ip == %s\n", inet_ntoa(icmpstats->src_ip));
					printf("icmp_type == %d\n", ntohl(icmpstats->icmp_type));
					printf("code == %d\n", ntohl(icmpstats->code));
					switch(ntohl(icmpstats->icmp_type)) {
						case ICMP_ECHOREPLY:
							printf("ECHO REPLY\n");
							break;
						case ICMP_DEST_UNREACH:
							printf("DESTINATION UNREACHABLE: ");
							switch(ntohl(icmpstats->code)) {
								case ICMP_NET_UNREACH:
									printf("NET UNREACHABLE\n");
									break;
								case ICMP_HOST_UNREACH:
									printf("HOST UNREACHABLE\n");
									break;
								case ICMP_PROT_UNREACH:
									printf("PROTOCOL UNREACHABLE\n");
									break;
								case ICMP_PORT_UNREACH:
									printf("PORT UNREACHABLE\n");
									break;
								case ICMP_FRAG_NEEDED:
									printf("FRAGMENTATION NEEDED, DF SET\n");
									break;
								case ICMP_SR_FAILED:
									printf("SOURCE ROUTE FAILED\n");
									break;
								case ICMP_NET_UNKNOWN:
									printf("NET UNKNOWN\n");
									break;
								case ICMP_HOST_UNKNOWN:
									printf("HOST UNKNOWN\n");
									break;
								case ICMP_HOST_ISOLATED:
									printf("HOST ISOLATED\n");
									break;
								case ICMP_PKT_FILTERED_NET:
									printf("ADMINISTRATIVELY PROHIBITED NETWORK FILTERED\n");
									break;
								case ICMP_PKT_FILTERED_HOST:
									printf("ADMINISTRATIVELY PROHIBITED HOST FILTERED\n");
									break;
								case ICMP_NET_UNR_TOS:
									printf("NET UNREACHABLE FOR TOS\n");
									break;
								case ICMP_HOST_UNR_TOS:
									printf("HOST UNREACHABLE FOR TOS\n");
									break;
								case ICMP_PKT_FILTERED:
									printf("ADMINISTRATIVELY PROHIBITED PACKET FILTERED\n");
									break;
								case ICMP_PREC_VIOLATION:
									printf("PREC VIOLATION\n");
									break;
								case ICMP_PREC_CUTOFF:
									printf("PREC CUTOFF\n");
									break;
								default:
									printf("UNKNOWN CODE\n");
									break;
							}
						case ICMP_SOURCE_QUENCH:
							printf("SOURCE QUENCH\n");
							break;
						case ICMP_REDIRECT:
							printf("REDIRECT: ");
							switch(ntohl(icmpstats->code)) {
								case ICMP_REDIR_NET:
									printf("NET\n");
									break;
								case ICMP_REDIR_HOST:
									printf("HOST\n");
									break;
								case ICMP_REDIR_TOS_NET:
									printf("TOS NET\n");
									break;
								case ICMP_REDIR_TOS_HOST:
									printf("TOS HOST\n");
									break;
							}
							break;
						case ICMP_ECHO:
							printf("ECHO\n");
							break;
						case ICMP_ROUTER_ADVERTISE:
							printf("ROUTER ADVERTISEMENT\n");
							break;
						case ICMP_ROUTER_SOLICIT:
							printf("ROUTER SOLICITATION\n");
							break;
						case ICMP_TIME_EXCEEDED:
							printf("TTL EXCEEDED: ");
							switch(ntohl(icmpstats->code)) {
								case ICMP_TIMEOUT_TRANSIT:
									printf("IN TRANSIT\n");
									break;
								case ICMP_TIMEOUT_REASSY:
									printf("TIME EXCEEDED IN FRAG REASSEMBLY\n");
									break;
							}
							break;
						case ICMP_PARAMETERPROB:
							printf("PARAMETER PROBLEM: ");
							switch(ntohl(icmpstats->code)) {
								case ICMP_PARAM_BADIPHDR:
									printf("BAD IP HEADER BYTE\n");
									break;
								case ICMP_PARAM_OPTMISSING:
									printf("OPTION MISSING\n");
									break;
								case ICMP_PARAM_BAD_LENGTH:
									printf("BAD LENGTH\n");
									break;
							}
							break;
						case ICMP_TIMESTAMP:
							printf("TIMESTAMP REQUEST\n");
							break;
						case ICMP_TIMESTAMPREPLY:
							printf("TIMESTAMP REPLY\n");
							break;
						case ICMP_INFO_REQUEST:
							printf("INFO REQUEST\n");
							break;
						case ICMP_INFO_REPLY:
							printf("INFO REPLY\n");
							break;
						case ICMP_ADDRESS:
							printf("ADDRESS REQUEST\n");
							break;
						case ICMP_ADDRESSREPLY:
							printf("ADDRESS REPLY\n");
							break;
						default:
							printf("UNKNOWN TYPE\n");
							break;
					}
					printf("num_badsum == %d\n", ntohl(icmpstats->num_badsum));
					printf("num_badipsum == %d\n", ntohl(icmpstats->num_badipsum));
					printf("num_frag == %d\n", ntohl(icmpstats->num_frag));
					printf("num_dontfrag == %d\n", ntohl(icmpstats->num_dontfrag));
				}
				else {
					// Version 2
					icmpstats_v2 = (struct ICMP_Stats_v2 *)msg;
					msg += sizeof(int32_t);
					fread(msg, 1, sizeof(struct ICMP_Stats_v2) - sizeof(int32_t), fpt);
					printf("remote_ip == %s\n", inet_ntoa(icmpstats_v2->remote_ip));
					printf("local_ip == %s\n", inet_ntoa(icmpstats_v2->local_ip));
					printf("local_netmask == %s\n", inet_ntoa(icmpstats_v2->local_netmask));
					printf("icmp_type == %d\n", icmpstats_v2->icmp_type);
					printf("icmp_code == %d\n", icmpstats_v2->icmp_code);
					switch(icmpstats_v2->icmp_type) {
						case ICMP_ECHOREPLY:
							printf("ECHO REPLY\n");
							break;
						case ICMP_DEST_UNREACH:
							printf("DESTINATION UNREACHABLE: ");
							switch(icmpstats_v2->icmp_code) {
								case ICMP_NET_UNREACH:
									printf("NET UNREACHABLE\n");
									break;
								case ICMP_HOST_UNREACH:
									printf("HOST UNREACHABLE\n");
									break;
								case ICMP_PROT_UNREACH:
									printf("PROTOCOL UNREACHABLE\n");
									break;
								case ICMP_PORT_UNREACH:
									printf("PORT UNREACHABLE\n");
									break;
								case ICMP_FRAG_NEEDED:
									printf("FRAGMENTATION NEEDED, DF SET\n");
									break;
								case ICMP_SR_FAILED:
									printf("SOURCE ROUTE FAILED\n");
									break;
								case ICMP_NET_UNKNOWN:
									printf("NET UNKNOWN\n");
									break;
								case ICMP_HOST_UNKNOWN:
									printf("HOST UNKNOWN\n");
									break;
								case ICMP_HOST_ISOLATED:
									printf("HOST ISOLATED\n");
									break;
								case ICMP_PKT_FILTERED_NET:
									printf("ADMINISTRATIVELY PROHIBITED NETWORK FILTERED\n");
									break;
								case ICMP_PKT_FILTERED_HOST:
									printf("ADMINISTRATIVELY PROHIBITED HOST FILTERED\n");
									break;
								case ICMP_NET_UNR_TOS:
									printf("NET UNREACHABLE FOR TOS\n");
									break;
								case ICMP_HOST_UNR_TOS:
									printf("HOST UNREACHABLE FOR TOS\n");
									break;
								case ICMP_PKT_FILTERED:
									printf("ADMINISTRATIVELY PROHIBITED PACKET FILTERED\n");
									break;
								case ICMP_PREC_VIOLATION:
									printf("PREC VIOLATION\n");
									break;
								case ICMP_PREC_CUTOFF:
									printf("PREC CUTOFF\n");
									break;
								default:
									printf("UNKNOWN CODE\n");
									break;
							}
						case ICMP_SOURCE_QUENCH:
							printf("SOURCE QUENCH\n");
							break;
						case ICMP_REDIRECT:
							printf("REDIRECT: ");
							switch(icmpstats_v2->icmp_code) {
								case ICMP_REDIR_NET:
									printf("NET\n");
									break;
								case ICMP_REDIR_HOST:
									printf("HOST\n");
									break;
								case ICMP_REDIR_TOS_NET:
									printf("TOS NET\n");
									break;
								case ICMP_REDIR_TOS_HOST:
									printf("TOS HOST\n");
									break;
							}
							break;
						case ICMP_ECHO:
							printf("ECHO\n");
							break;
						case ICMP_ROUTER_ADVERTISE:
							printf("ROUTER ADVERTISEMENT\n");
							break;
						case ICMP_ROUTER_SOLICIT:
							printf("ROUTER SOLICITATION\n");
							break;
						case ICMP_TIME_EXCEEDED:
							printf("TTL EXCEEDED: ");
							switch(icmpstats_v2->icmp_code) {
								case ICMP_TIMEOUT_TRANSIT:
									printf("IN TRANSIT\n");
									break;
								case ICMP_TIMEOUT_REASSY:
									printf("TIME EXCEEDED IN FRAG REASSEMBLY\n");
									break;
							}
							break;
						case ICMP_PARAMETERPROB:
							printf("PARAMETER PROBLEM: ");
							switch(icmpstats_v2->icmp_code) {
								case ICMP_PARAM_BADIPHDR:
									printf("BAD IP HEADER BYTE\n");
									break;
								case ICMP_PARAM_OPTMISSING:
									printf("OPTION MISSING\n");
									break;
								case ICMP_PARAM_BAD_LENGTH:
									printf("BAD LENGTH\n");
									break;
							}
							break;
						case ICMP_TIMESTAMP:
							printf("TIMESTAMP REQUEST\n");
							break;
						case ICMP_TIMESTAMPREPLY:
							printf("TIMESTAMP REPLY\n");
							break;
						case ICMP_INFO_REQUEST:
							printf("INFO REQUEST\n");
							break;
						case ICMP_INFO_REPLY:
							printf("INFO REPLY\n");
							break;
						case ICMP_ADDRESS:
							printf("ADDRESS REQUEST\n");
							break;
						case ICMP_ADDRESSREPLY:
							printf("ADDRESS REPLY\n");
							break;
						default:
							printf("UNKNOWN TYPE\n");
							break;
					}
					printf("num_noicmpsum == %u\n", ntohl(icmpstats_v2->num_noicmpsum));
					printf("num_badicmpsum == %u\n", ntohl(icmpstats_v2->num_badicmpsum));
					printf("num_badipsum == %u\n", ntohl(icmpstats_v2->num_badipsum));
					printf("num_frag_sent == %u\n", ntohl(icmpstats_v2->num_frag_sent));
					printf("num_frag_received == %u\n", ntohl(icmpstats_v2->num_frag_received));
					printf("num_dontfrag_sent == %u\n", ntohl(icmpstats_v2->num_dontfrag_sent));
					printf("num_dontfrag_received == %u\n", ntohl(icmpstats_v2->num_dontfrag_received));
					printf("local_min_ttl == %d\n", icmpstats_v2->local_min_ttl);
					printf("local_max_ttl == %d\n", icmpstats_v2->local_max_ttl);
					printf("remote_min_ttl == %d\n", icmpstats_v2->remote_min_ttl);
					printf("remote_max_ttl == %d\n", icmpstats_v2->remote_max_ttl);
					temptime = ntohl(icmpstats_v2->time_first_packet.tv_sec);
					printf("time_first_packet (using ctime, no usecs) == %s", ctime(&temptime));
					printf("time_first_packet == %u.%06u\n", ntohl(icmpstats_v2->time_first_packet.tv_sec), ntohl(icmpstats_v2->time_first_packet.tv_usec));
					temptime = ntohl(icmpstats_v2->time_last_packet.tv_sec);
					printf("time_last_packet (using ctime, no usecs) == %s", ctime(&temptime));
					printf("time_last_packet == %u.%06u\n", ntohl(icmpstats_v2->time_last_packet.tv_sec), ntohl(icmpstats_v2->time_last_packet.tv_usec));
				}
				printf("======================================================================\n");
				msg = orig;
			}
			else if(ntohl(*type) == NETI_IGMP_FLOW) {
				printf("IGMP Flow\n");
				igmpstats = NULL;
				igmpstats_v2 = NULL;
				if(version < 19) {
					// Version 1
					igmpstats = (struct IGMP_Stats *)msg;
					msg += sizeof(int32_t);
					fread(msg, 1, sizeof(struct IGMP_Stats) - sizeof(int32_t), fpt);
					printf("dest_ip == %s\n", inet_ntoa(igmpstats->dest_ip));
					printf("src_ip == %s\n", inet_ntoa(igmpstats->src_ip));
					printf("mcast_ip == %s\n", inet_ntoa(igmpstats->mcast_ip));
					printf("version == %d\n", ntohl(igmpstats->version));
					printf("igmp_type == %d\n", ntohl(igmpstats->igmp_type));
					printf("num_badsum == %d\n", ntohl(igmpstats->num_badsum));
					printf("num_badipsum == %d\n", ntohl(igmpstats->num_badipsum));
					printf("num_packets == %d\n", ntohl(igmpstats->num_packets));
					printf("num_frag == %d\n", ntohl(igmpstats->num_frag));
					printf("num_dontfrag == %d\n", ntohl(igmpstats->num_dontfrag));
					printf("max_response_time == %d\n", ntohl(igmpstats->max_response_time));
					temptime = ntohl(igmpstats->time_first_packet.tv_sec);
					printf("time_first_packet (using ctime, no usecs) == %s", ctime(&temptime));
					printf("time_first_packet == %u.%06u\n", ntohl(igmpstats->time_first_packet.tv_sec), ntohl(igmpstats->time_first_packet.tv_usec));
					temptime = ntohl(igmpstats->time_last_packet.tv_sec);
					printf("time_last_packet (using ctime, no usecs) == %s", ctime(&temptime));
					printf("time_last_packet == %u.%06u\n", ntohl(igmpstats->time_last_packet.tv_sec), ntohl(igmpstats->time_last_packet.tv_usec));
				}
				else {
					// Version 2
					igmpstats_v2 = (struct IGMP_Stats_v2 *)msg;
					msg += sizeof(int32_t);
					fread(msg, 1, sizeof(struct IGMP_Stats_v2) - sizeof(int32_t), fpt);
					printf("dest_ip == %s\n", inet_ntoa(igmpstats_v2->dest_ip));
					printf("src_ip == %s\n", inet_ntoa(igmpstats_v2->src_ip));
					printf("mcast_ip == %s\n", inet_ntoa(igmpstats_v2->mcast_ip));
					printf("local_netmask == %s\n", inet_ntoa(igmpstats_v2->local_netmask));
					printf("igmp_type == %d\n", igmpstats_v2->igmp_type);
					printf("igmp_mrt == %d\n", igmpstats_v2->igmp_mrt);
					printf("TTL == %d\n", igmpstats_v2->ttl);
					if(igmpstats_v2->flags & 0x20) {
						printf("IGMP Checksum Not Calculated\n");
					}
					if(igmpstats_v2->flags & 0x10) {
						printf("Direction: Local --> Remote\n");
					}
					else {
						printf("Direction: Remote --> Local\n");
					}
					if(igmpstats_v2->flags & 0x08) {
						printf("IGMP Checksum Bad\n");
					}
					else {
						printf("IGMP Checksum OK\n");
					}
					if(igmpstats_v2->flags & 0x04) {
						printf("IP Checksum Bad\n");
					}
					else {
						printf("IP Checksum OK\n");
					}
					if(igmpstats_v2->flags & 0x02) {
						printf("Fragment Flag Set\n");
					}
					else {
						printf("Fragment Flag Not Set\n");
					}
					if(igmpstats_v2->flags & 0x01) {
						printf("Don't Fragment Flag Set\n");
					}
					else {
						printf("Don't Fragment Flag Not Set\n");
					}
					temptime = ntohl(igmpstats_v2->time_of_packet.tv_sec);
					printf("time_of_packet (using ctime, no usecs) == %s", ctime(&temptime));
					printf("time_of_packet == %u.%06u\n", ntohl(igmpstats_v2->time_of_packet.tv_sec), ntohl(igmpstats_v2->time_of_packet.tv_usec));
				}
				printf("======================================================================\n");
				msg = orig;
			}
			else {
				printf("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
				printf("NETI@home Error: Unknown Packet Type\n");
				printf("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
				parseerrs++;
			}
			fread(msg, 1, sizeof(int32_t), fpt);
		}
		fclose(fpt);
		filecount--;
	} while(filecount > 0);

	free(msg);
	printf("parseerrs == %d\n", parseerrs);
	return 0;
}

