; * Copyright 2003-2005 Charles Robert Simpson, Jr.
; *
; * This file is part of NETI@home.
; * 
; * NETI@home is free software; you can redistribute it and/or modify
; * it under the terms of the GNU General Public License as published by
; * the Free Software Foundation; either version 2 of the License, or
; * (at your option) any later version.
; * 
; * NETI@home is distributed in the hope that it will be useful,
; * but WITHOUT ANY WARRANTY; without even the implied warranty of
; * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; * GNU General Public License for more details.
; * 
; * You should have received a copy of the GNU General Public License
; * along with NETI@home; if not, write to the Free Software
; * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
; *

;--------------------------------
;Include Modern UI

  !include "MUI.nsh"

;--------------------------------

; -------------------------------
; Start

  ; Use this define to install WinPcap
  !define INSTALLPCAP

  !define PROGRAM_NAME "NETI@home"
  !define VERSION "2.0"
  Name "${PROGRAM_NAME} ${VERSION}"
  CRCCheck On

;--------------------------------
;General

  !ifdef INSTALLPCAP
  OutFile "NETI-setup-${VERSION}-pcap.exe"
  !else
  OutFile "NETI-setup-${VERSION}-nopcap.exe"
  !endif
  XPStyle on
  ShowInstDetails show
  ;ShowUninstDetails show
  ;SetCompressor "bzip2"
 
;--------------------------------
;Folder selection page

  InstallDir "$PROGRAMFILES\${PROGRAM_NAME}"


;--------------------------------
;Modern UI Configuration

  !define MUI_ICON "neti.ico"
  !define MUI_UNICON "neti.ico"
  !define MUI_ABORTWARNING

;--------------------------------
;Pages

  !insertmacro MUI_PAGE_WELCOME
  !insertmacro MUI_PAGE_LICENSE "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\COPYING"
  !insertmacro MUI_PAGE_COMPONENTS
  !ifdef INSTALLPCAP
  Page custom WinPcap		; Custom page to install WinPcap
  !endif
  !define MUI_DIRECTORYPAGE_TEXT_DESTINATION "Note:"
  !insertmacro MUI_PAGE_DIRECTORY
  Page custom SetDevice		; Custom page to select interface(s) to monitor
  Page custom SetProperties	; Custom page to select privacy level and maximum log file size
  Page custom SetLocation	; Custom page to select location, zip, and email (optional)
  ;STARTMENU?
  !insertmacro MUI_PAGE_INSTFILES
  ; Use the following line for debugging
  ;!define MUI_FINISHPAGE_NOAUTOCLOSE
  !insertmacro MUI_PAGE_FINISH
  
  !insertmacro MUI_UNPAGE_WELCOME
  !insertmacro MUI_UNPAGE_CONFIRM
  !insertmacro MUI_UNPAGE_INSTFILES
  ; Use the following line for debugging
  ;!define MUI_UNFINISHPAGE_NOAUTOCLOSE
  !insertmacro MUI_UNPAGE_FINISH
  
;--------------------------------

;--------------------------------
;Language

  !insertmacro MUI_LANGUAGE "English"


;-------------------------------- 

;-------------------------------- 
;Reserve Files
  ; These files should be inserted before other files in the data block
  ; Keep these lines before any File command
  ; Only for solid compression (by default, solid compression is enabled for BZIP2 and LZMA)

  !ifdef INSTALLPCAP
  ReserveFile "netipcap.ini"
  !endif
  ReserveFile "netiprop.ini"
  ReserveFile "netidev.ini"
  ReserveFile "netiloc.ini"
  ReserveFile "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home devselect\Debug\devselect.exe"
  !ifdef INSTALLPCAP
  ReserveFile "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\windows\WinPcap_3_1_beta4_nogui_noreboot_nobanner.exe"
  !endif
  !insertmacro MUI_RESERVEFILE_INSTALLOPTIONS

;-------------------------------- 

;Installer Sections     
Section "-Required"

;Set for All Users
  SetShellVarContext all

;Add files
  SetOutPath "$INSTDIR"		;NETI@home Directory
  
  ; Create neti.conf
  FileOpen $4 "$INSTDIR\neti.conf" w
  FileWrite $4 "# Privacy setting can be LOW, MEDIUM, or HIGH$\r$\n"
  FileWrite $4 "#$\r$\n"
  FileWrite $4 "# LOW privacy will cause NETI@home to collect$\r$\n"
  FileWrite $4 "#$\tand report the full local, remote, and multicast IP addresses$\r$\n"
  FileWrite $4 "# MEDIUM (default) privacy will cause NETI@home to report only the$\r$\n"
  FileWrite $4 "#$\tnetwork portion of the local, remote, and multicast IP addresses$\r$\n"
  FileWrite $4 "# HIGH privacy will cause NETI@home to not report any IP addresses$\r$\n"
  ; LOW Privacy
  !insertmacro MUI_INSTALLOPTIONS_READ $R0 "netiprop.ini" "Field 2" "State"
  StrCmp "1" $R0 "" lbl_highpriv
  FileWrite $4 "PRIVACY = LOW$\r$\n"
  Goto lbl_logfile
lbl_highpriv:
  ; HIGH Privacy
  !insertmacro MUI_INSTALLOPTIONS_READ $R0 "netiprop.ini" "Field 4" "State"
  StrCmp "1" $R0 "" lbl_medpriv
  FileWrite $4 "PRIVACY = HIGH$\r$\n"
  Goto lbl_logfile
lbl_medpriv:
  ; MEDIUM Privacy
  FileWrite $4 "PRIVACY = MEDIUM$\r$\n"
lbl_logfile:
  FileWrite $4 "$\r$\n"
  FileWrite $4 "# Maximum Log File Size (in Bytes)$\r$\n"
  ; Maximum Log File Size
  !insertmacro MUI_INSTALLOPTIONS_READ $R0 "netiprop.ini" "Field 6" "State"
  StrCmp "1 KByte" $R0 "" lbl_10KB
  FileWrite $4 "LOGFILESIZE = 1000$\r$\n"
  Goto lbl_logdone
lbl_10KB:
  StrCmp "10 KByte" $R0 "" lbl_100KB
  FileWrite $4 "LOGFILESIZE = 10000$\r$\n"
  Goto lbl_logdone
lbl_100KB:
  StrCmp "100 KByte" $R0 "" lbl_10MB
  FileWrite $4 "LOGFILESIZE = 100000$\r$\n"
  Goto lbl_logdone
lbl_10MB:
  StrCmp "10 MByte" $R0 "" lbl_1MB
  FileWrite $4 "LOGFILESIZE = 10000000$\r$\n"
  Goto lbl_logdone
lbl_1MB:
  FileWrite $4 "LOGFILESIZE = 1000000$\r$\n"
lbl_logdone:
  FileWrite $4 "$\r$\n"
  FileWrite $4 "# The interface that you would like NETI@home to monitor.$\r$\n"
  FileWrite $4 "#$\tYou may also specify the interface on the command line,$\r$\n"
  FileWrite $4 "#$\tor if no interface is specified on the command line$\r$\n"
  FileWrite $4 "#$\tor here in the configuration file,$\r$\n"
  FileWrite $4 "#$\tthen the default interface is selected.$\r$\n"
  ; Interface
  !insertmacro MUI_INSTALLOPTIONS_READ $R0 "netidev.ini" "Field 2" "State"
  FileWrite $4 "INTERFACE = $\"$R0$\"$\r$\n"
  FileWrite $4 "$\r$\n"
  FileWrite $4 "# The geographical location where you are located.$\r$\n"
  FileWrite $4 "#$\tLocation is a number from 0 to 262 and these numbers$\r$\n"
  FileWrite $4 "#$\tare defined in the locations.h file.$\r$\n"
  ; Location
  !insertmacro MUI_INSTALLOPTIONS_READ $R0 "netiloc.ini" "Field 2" "State"
  StrCmp "Unknown" $R0 "" lbl_intrfc1
  FileWrite $4 "LOCATION = 0$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc1:
  StrCmp "Afghanistan" $R0 "" lbl_intrfc2
  FileWrite $4 "LOCATION = 1$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc2:
  StrCmp "Albania" $R0 "" lbl_intrfc3
  FileWrite $4 "LOCATION = 2$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc3:
  StrCmp "Algeria" $R0 "" lbl_intrfc4
  FileWrite $4 "LOCATION = 3$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc4:
  StrCmp "American Samoa" $R0 "" lbl_intrfc5
  FileWrite $4 "LOCATION = 4$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc5:
  StrCmp "Andorra" $R0 "" lbl_intrfc6
  FileWrite $4 "LOCATION = 5$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc6:
  StrCmp "Angola" $R0 "" lbl_intrfc7
  FileWrite $4 "LOCATION = 6$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc7:
  StrCmp "Anguilla" $R0 "" lbl_intrfc8
  FileWrite $4 "LOCATION = 7$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc8:
  StrCmp "Antigua and Barbuda" $R0 "" lbl_intrfc9
  FileWrite $4 "LOCATION = 8$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc9:
  StrCmp "Argentina" $R0 "" lbl_intrfc10
  FileWrite $4 "LOCATION = 9$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc10:
  StrCmp "Armenia" $R0 "" lbl_intrfc11
  FileWrite $4 "LOCATION = 10$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc11:
  StrCmp "Aruba" $R0 "" lbl_intrfc12
  FileWrite $4 "LOCATION = 11$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc12:
  StrCmp "Ashmore and Cartier Islands" $R0 "" lbl_intrfc13
  FileWrite $4 "LOCATION = 12$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc13:
  StrCmp "Australia" $R0 "" lbl_intrfc14
  FileWrite $4 "LOCATION = 13$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc14:
  StrCmp "Austria" $R0 "" lbl_intrfc15
  FileWrite $4 "LOCATION = 14$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc15:
  StrCmp "Azerbaijan" $R0 "" lbl_intrfc16
  FileWrite $4 "LOCATION = 15$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc16:
  StrCmp "The Bahamas" $R0 "" lbl_intrfc17
  FileWrite $4 "LOCATION = 16$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc17:
  StrCmp "Bahrain" $R0 "" lbl_intrfc18
  FileWrite $4 "LOCATION = 17$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc18:
  StrCmp "Baker Island" $R0 "" lbl_intrfc19
  FileWrite $4 "LOCATION = 18$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc19:
  StrCmp "Bangladesh" $R0 "" lbl_intrfc20
  FileWrite $4 "LOCATION = 19$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc20:
  StrCmp "Barbados" $R0 "" lbl_intrfc21
  FileWrite $4 "LOCATION = 20$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc21:
  StrCmp "Bassas da India" $R0 "" lbl_intrfc22
  FileWrite $4 "LOCATION = 21$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc22:
  StrCmp "Belarus" $R0 "" lbl_intrfc23
  FileWrite $4 "LOCATION = 22$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc23:
  StrCmp "Belgium" $R0 "" lbl_intrfc24
  FileWrite $4 "LOCATION = 23$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc24:
  StrCmp "Belize" $R0 "" lbl_intrfc25
  FileWrite $4 "LOCATION = 24$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc25:
  StrCmp "Benin" $R0 "" lbl_intrfc26
  FileWrite $4 "LOCATION = 25$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc26:
  StrCmp "Bermuda" $R0 "" lbl_intrfc27
  FileWrite $4 "LOCATION = 26$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc27:
  StrCmp "Bhutan" $R0 "" lbl_intrfc28
  FileWrite $4 "LOCATION = 27$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc28:
  StrCmp "Bolivia" $R0 "" lbl_intrfc29
  FileWrite $4 "LOCATION = 28$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc29:
  StrCmp "Bosnia and Herzegovina" $R0 "" lbl_intrfc30
  FileWrite $4 "LOCATION = 29$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc30:
  StrCmp "Botswana" $R0 "" lbl_intrfc31
  FileWrite $4 "LOCATION = 30$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc31:
  StrCmp "Bouvet Island" $R0 "" lbl_intrfc32
  FileWrite $4 "LOCATION = 31$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc32:
  StrCmp "Brazil" $R0 "" lbl_intrfc33
  FileWrite $4 "LOCATION = 32$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc33:
  StrCmp "British Indian Ocean Territory" $R0 "" lbl_intrfc34
  FileWrite $4 "LOCATION = 33$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc34:
  StrCmp "British Virgin Islands" $R0 "" lbl_intrfc35
  FileWrite $4 "LOCATION = 34$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc35:
  StrCmp "Brunei" $R0 "" lbl_intrfc36
  FileWrite $4 "LOCATION = 35$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc36:
  StrCmp "Bulgaria" $R0 "" lbl_intrfc37
  FileWrite $4 "LOCATION = 36$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc37:
  StrCmp "Burkina Faso" $R0 "" lbl_intrfc38
  FileWrite $4 "LOCATION = 37$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc38:
  StrCmp "Burma" $R0 "" lbl_intrfc39
  FileWrite $4 "LOCATION = 38$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc39:
  StrCmp "Burundi" $R0 "" lbl_intrfc40
  FileWrite $4 "LOCATION = 39$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc40:
  StrCmp "Cambodia" $R0 "" lbl_intrfc41
  FileWrite $4 "LOCATION = 40$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc41:
  StrCmp "Cameroon" $R0 "" lbl_intrfc42
  FileWrite $4 "LOCATION = 41$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc42:
  StrCmp "Canada" $R0 "" lbl_intrfc43
  FileWrite $4 "LOCATION = 42$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc43:
  StrCmp "Cape Verde" $R0 "" lbl_intrfc44
  FileWrite $4 "LOCATION = 43$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc44:
  StrCmp "Cayman Islands" $R0 "" lbl_intrfc45
  FileWrite $4 "LOCATION = 44$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc45:
  StrCmp "Central African Republic" $R0 "" lbl_intrfc46
  FileWrite $4 "LOCATION = 45$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc46:
  StrCmp "Chad" $R0 "" lbl_intrfc47
  FileWrite $4 "LOCATION = 46$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc47:
  StrCmp "Chile" $R0 "" lbl_intrfc48
  FileWrite $4 "LOCATION = 47$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc48:
  StrCmp "China" $R0 "" lbl_intrfc49
  FileWrite $4 "LOCATION = 48$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc49:
  StrCmp "Christmas Island" $R0 "" lbl_intrfc50
  FileWrite $4 "LOCATION = 49$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc50:
  StrCmp "Clipperton Island" $R0 "" lbl_intrfc51
  FileWrite $4 "LOCATION = 50$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc51:
  StrCmp "Cocos (Keeling) Islands" $R0 "" lbl_intrfc52
  FileWrite $4 "LOCATION = 51$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc52:
  StrCmp "Colombia" $R0 "" lbl_intrfc53
  FileWrite $4 "LOCATION = 52$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc53:
  StrCmp "Comoros" $R0 "" lbl_intrfc54
  FileWrite $4 "LOCATION = 53$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc54:
  StrCmp "Congo" $R0 "" lbl_intrfc55
  FileWrite $4 "LOCATION = 54$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc55:
  StrCmp "Congo, Democratic Republic of" $R0 "" lbl_intrfc56
  FileWrite $4 "LOCATION = 55$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc56:
  StrCmp "Cook Islands" $R0 "" lbl_intrfc57
  FileWrite $4 "LOCATION = 56$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc57:
  StrCmp "Coral Sea Islands" $R0 "" lbl_intrfc58
  FileWrite $4 "LOCATION = 57$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc58:
  StrCmp "Costa Rica" $R0 "" lbl_intrfc59
  FileWrite $4 "LOCATION = 58$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc59:
  StrCmp "Cote d'Ivoire" $R0 "" lbl_intrfc60
  FileWrite $4 "LOCATION = 59$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc60:
  StrCmp "Croatia" $R0 "" lbl_intrfc61
  FileWrite $4 "LOCATION = 60$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc61:
  StrCmp "Cuba" $R0 "" lbl_intrfc62
  FileWrite $4 "LOCATION = 61$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc62:
  StrCmp "Cyprus" $R0 "" lbl_intrfc63
  FileWrite $4 "LOCATION = 62$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc63:
  StrCmp "Czech Republic" $R0 "" lbl_intrfc64
  FileWrite $4 "LOCATION = 63$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc64:
  StrCmp "Denmark" $R0 "" lbl_intrfc65
  FileWrite $4 "LOCATION = 64$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc65:
  StrCmp "Djibouti" $R0 "" lbl_intrfc66
  FileWrite $4 "LOCATION = 65$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc66:
  StrCmp "Dominica" $R0 "" lbl_intrfc67
  FileWrite $4 "LOCATION = 66$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc67:
  StrCmp "Dominican Republic" $R0 "" lbl_intrfc68
  FileWrite $4 "LOCATION = 67$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc68:
  StrCmp "East Timor" $R0 "" lbl_intrfc69
  FileWrite $4 "LOCATION = 68$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc69:
  StrCmp "Ecuador" $R0 "" lbl_intrfc70
  FileWrite $4 "LOCATION = 69$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc70:
  StrCmp "Egypt" $R0 "" lbl_intrfc71
  FileWrite $4 "LOCATION = 70$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc71:
  StrCmp "El Salvador" $R0 "" lbl_intrfc72
  FileWrite $4 "LOCATION = 71$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc72:
  StrCmp "Equatorial Guinea" $R0 "" lbl_intrfc73
  FileWrite $4 "LOCATION = 72$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc73:
  StrCmp "Eritrea" $R0 "" lbl_intrfc74
  FileWrite $4 "LOCATION = 73$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc74:
  StrCmp "Estonia" $R0 "" lbl_intrfc75
  FileWrite $4 "LOCATION = 74$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc75:
  StrCmp "Ethiopia" $R0 "" lbl_intrfc76
  FileWrite $4 "LOCATION = 75$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc76:
  StrCmp "Europa Island" $R0 "" lbl_intrfc77
  FileWrite $4 "LOCATION = 76$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc77:
  StrCmp "Falkland Islands (Islas Malvinas)" $R0 "" lbl_intrfc78
  FileWrite $4 "LOCATION = 77$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc78:
  StrCmp "Faroe Islands" $R0 "" lbl_intrfc79
  FileWrite $4 "LOCATION = 78$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc79:
  StrCmp "Fiji" $R0 "" lbl_intrfc80
  FileWrite $4 "LOCATION = 79$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc80:
  StrCmp "Finland" $R0 "" lbl_intrfc81
  FileWrite $4 "LOCATION = 80$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc81:
  StrCmp "France" $R0 "" lbl_intrfc82
  FileWrite $4 "LOCATION = 81$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc82:
  StrCmp "French Guiana" $R0 "" lbl_intrfc83
  FileWrite $4 "LOCATION = 82$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc83:
  StrCmp "French Polynesia" $R0 "" lbl_intrfc84
  FileWrite $4 "LOCATION = 83$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc84:
  StrCmp "French Southern and Antarctic Lands" $R0 "" lbl_intrfc85
  FileWrite $4 "LOCATION = 84$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc85:
  StrCmp "Gabon" $R0 "" lbl_intrfc86
  FileWrite $4 "LOCATION = 85$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc86:
  StrCmp "The Gambia" $R0 "" lbl_intrfc87
  FileWrite $4 "LOCATION = 86$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc87:
  StrCmp "Georgia" $R0 "" lbl_intrfc88
  FileWrite $4 "LOCATION = 87$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc88:
  StrCmp "Germany" $R0 "" lbl_intrfc89
  FileWrite $4 "LOCATION = 88$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc89:
  StrCmp "Ghana" $R0 "" lbl_intrfc90
  FileWrite $4 "LOCATION = 89$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc90:
  StrCmp "Gibraltar" $R0 "" lbl_intrfc91
  FileWrite $4 "LOCATION = 90$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc91:
  StrCmp "Glorioso Islands" $R0 "" lbl_intrfc92
  FileWrite $4 "LOCATION = 91$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc92:
  StrCmp "Greece" $R0 "" lbl_intrfc93
  FileWrite $4 "LOCATION = 92$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc93:
  StrCmp "Greenland" $R0 "" lbl_intrfc94
  FileWrite $4 "LOCATION = 93$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc94:
  StrCmp "Grenada" $R0 "" lbl_intrfc95
  FileWrite $4 "LOCATION = 94$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc95:
  StrCmp "Guadeloupe" $R0 "" lbl_intrfc96
  FileWrite $4 "LOCATION = 95$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc96:
  StrCmp "Guam" $R0 "" lbl_intrfc97
  FileWrite $4 "LOCATION = 96$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc97:
  StrCmp "Guatemala" $R0 "" lbl_intrfc98
  FileWrite $4 "LOCATION = 97$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc98:
  StrCmp "Guernsey" $R0 "" lbl_intrfc99
  FileWrite $4 "LOCATION = 98$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc99:
  StrCmp "Guinea" $R0 "" lbl_intrfc100
  FileWrite $4 "LOCATION = 99$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc100:
  StrCmp "Guinea-Bissau" $R0 "" lbl_intrfc101
  FileWrite $4 "LOCATION = 100$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc101:
  StrCmp "Guyana" $R0 "" lbl_intrfc102
  FileWrite $4 "LOCATION = 101$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc102:
  StrCmp "Haiti" $R0 "" lbl_intrfc103
  FileWrite $4 "LOCATION = 102$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc103:
  StrCmp "Heard Island and McDonald Islands" $R0 "" lbl_intrfc104
  FileWrite $4 "LOCATION = 103$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc104:
  StrCmp "Honduras" $R0 "" lbl_intrfc105
  FileWrite $4 "LOCATION = 104$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc105:
  StrCmp "Howland Island" $R0 "" lbl_intrfc106
  FileWrite $4 "LOCATION = 105$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc106:
  StrCmp "Hungary" $R0 "" lbl_intrfc107
  FileWrite $4 "LOCATION = 106$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc107:
  StrCmp "Iceland" $R0 "" lbl_intrfc108
  FileWrite $4 "LOCATION = 107$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc108:
  StrCmp "India" $R0 "" lbl_intrfc109
  FileWrite $4 "LOCATION = 108$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc109:
  StrCmp "Indonesia" $R0 "" lbl_intrfc110
  FileWrite $4 "LOCATION = 109$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc110:
  StrCmp "Iran" $R0 "" lbl_intrfc111
  FileWrite $4 "LOCATION = 110$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc111:
  StrCmp "Iraq" $R0 "" lbl_intrfc112
  FileWrite $4 "LOCATION = 111$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc112:
  StrCmp "Ireland" $R0 "" lbl_intrfc113
  FileWrite $4 "LOCATION = 112$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc113:
  StrCmp "Israel" $R0 "" lbl_intrfc114
  FileWrite $4 "LOCATION = 113$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc114:
  StrCmp "Italy" $R0 "" lbl_intrfc115
  FileWrite $4 "LOCATION = 114$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc115:
  StrCmp "Jamaica" $R0 "" lbl_intrfc116
  FileWrite $4 "LOCATION = 115$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc116:
  StrCmp "Jan Mayen" $R0 "" lbl_intrfc117
  FileWrite $4 "LOCATION = 116$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc117:
  StrCmp "Japan" $R0 "" lbl_intrfc118
  FileWrite $4 "LOCATION = 117$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc118:
  StrCmp "Jarvis Island" $R0 "" lbl_intrfc119
  FileWrite $4 "LOCATION = 118$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc119:
  StrCmp "Jersey" $R0 "" lbl_intrfc120
  FileWrite $4 "LOCATION = 119$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc120:
  StrCmp "Johnston Atoll" $R0 "" lbl_intrfc121
  FileWrite $4 "LOCATION = 120$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc121:
  StrCmp "Jordan" $R0 "" lbl_intrfc122
  FileWrite $4 "LOCATION = 121$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc122:
  StrCmp "Juan de Nova Island" $R0 "" lbl_intrfc123
  FileWrite $4 "LOCATION = 122$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc123:
  StrCmp "Kazakhstan" $R0 "" lbl_intrfc124
  FileWrite $4 "LOCATION = 123$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc124:
  StrCmp "Kenya" $R0 "" lbl_intrfc125
  FileWrite $4 "LOCATION = 124$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc125:
  StrCmp "Kingman Reef" $R0 "" lbl_intrfc126
  FileWrite $4 "LOCATION = 125$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc126:
  StrCmp "Kiribati" $R0 "" lbl_intrfc127
  FileWrite $4 "LOCATION = 126$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc127:
  StrCmp "Korea, North" $R0 "" lbl_intrfc128
  FileWrite $4 "LOCATION = 127$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc128:
  StrCmp "Korea, South" $R0 "" lbl_intrfc129
  FileWrite $4 "LOCATION = 128$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc129:
  StrCmp "Kuwait" $R0 "" lbl_intrfc130
  FileWrite $4 "LOCATION = 129$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc130:
  StrCmp "Kyrgyzstan" $R0 "" lbl_intrfc131
  FileWrite $4 "LOCATION = 130$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc131:
  StrCmp "Laos" $R0 "" lbl_intrfc132
  FileWrite $4 "LOCATION = 131$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc132:
  StrCmp "Latvia" $R0 "" lbl_intrfc133
  FileWrite $4 "LOCATION = 132$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc133:
  StrCmp "Lebanon" $R0 "" lbl_intrfc134
  FileWrite $4 "LOCATION = 133$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc134:
  StrCmp "Lesotho" $R0 "" lbl_intrfc135
  FileWrite $4 "LOCATION = 134$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc135:
  StrCmp "Liberia" $R0 "" lbl_intrfc136
  FileWrite $4 "LOCATION = 135$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc136:
  StrCmp "Libya" $R0 "" lbl_intrfc137
  FileWrite $4 "LOCATION = 136$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc137:
  StrCmp "Liechtenstein" $R0 "" lbl_intrfc138
  FileWrite $4 "LOCATION = 137$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc138:
  StrCmp "Lithuania" $R0 "" lbl_intrfc139
  FileWrite $4 "LOCATION = 138$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc139:
  StrCmp "Luxembourg" $R0 "" lbl_intrfc140
  FileWrite $4 "LOCATION = 139$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc140:
  StrCmp "Macau" $R0 "" lbl_intrfc141
  FileWrite $4 "LOCATION = 140$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc141:
  StrCmp "Macedonia" $R0 "" lbl_intrfc142
  FileWrite $4 "LOCATION = 141$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc142:
  StrCmp "Madagascar" $R0 "" lbl_intrfc143
  FileWrite $4 "LOCATION = 142$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc143:
  StrCmp "Malawi" $R0 "" lbl_intrfc144
  FileWrite $4 "LOCATION = 143$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc144:
  StrCmp "Malaysia" $R0 "" lbl_intrfc145
  FileWrite $4 "LOCATION = 144$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc145:
  StrCmp "Maldives" $R0 "" lbl_intrfc146
  FileWrite $4 "LOCATION = 145$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc146:
  StrCmp "Mali" $R0 "" lbl_intrfc147
  FileWrite $4 "LOCATION = 146$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc147:
  StrCmp "Malta" $R0 "" lbl_intrfc148
  FileWrite $4 "LOCATION = 147$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc148:
  StrCmp "Man, Isle of" $R0 "" lbl_intrfc149
  FileWrite $4 "LOCATION = 148$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc149:
  StrCmp "Marshall Islands" $R0 "" lbl_intrfc150
  FileWrite $4 "LOCATION = 149$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc150:
  StrCmp "Martinique" $R0 "" lbl_intrfc151
  FileWrite $4 "LOCATION = 150$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc151:
  StrCmp "Mauritania" $R0 "" lbl_intrfc152
  FileWrite $4 "LOCATION = 151$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc152:
  StrCmp "Mauritius" $R0 "" lbl_intrfc153
  FileWrite $4 "LOCATION = 152$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc153:
  StrCmp "Mayotte" $R0 "" lbl_intrfc154
  FileWrite $4 "LOCATION = 153$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc154:
  StrCmp "Mexico" $R0 "" lbl_intrfc155
  FileWrite $4 "LOCATION = 154$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc155:
  StrCmp "Micronesia, Federated States of" $R0 "" lbl_intrfc156
  FileWrite $4 "LOCATION = 155$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc156:
  StrCmp "Midway Islands" $R0 "" lbl_intrfc157
  FileWrite $4 "LOCATION = 156$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc157:
  StrCmp "Moldova" $R0 "" lbl_intrfc158
  FileWrite $4 "LOCATION = 157$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc158:
  StrCmp "Monaco" $R0 "" lbl_intrfc159
  FileWrite $4 "LOCATION = 158$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc159:
  StrCmp "Mongolia" $R0 "" lbl_intrfc160
  FileWrite $4 "LOCATION = 159$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc160:
  StrCmp "Montserrat" $R0 "" lbl_intrfc161
  FileWrite $4 "LOCATION = 160$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc161:
  StrCmp "Morocco" $R0 "" lbl_intrfc162
  FileWrite $4 "LOCATION = 161$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc162:
  StrCmp "Mozambique" $R0 "" lbl_intrfc163
  FileWrite $4 "LOCATION = 162$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc163:
  StrCmp "Myanmar" $R0 "" lbl_intrfc164
  FileWrite $4 "LOCATION = 163$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc164:
  StrCmp "Namibia" $R0 "" lbl_intrfc165
  FileWrite $4 "LOCATION = 164$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc165:
  StrCmp "Nauru" $R0 "" lbl_intrfc166
  FileWrite $4 "LOCATION = 165$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc166:
  StrCmp "Navassa Island" $R0 "" lbl_intrfc167
  FileWrite $4 "LOCATION = 166$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc167:
  StrCmp "Nepal" $R0 "" lbl_intrfc168
  FileWrite $4 "LOCATION = 167$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc168:
  StrCmp "Netherlands" $R0 "" lbl_intrfc169
  FileWrite $4 "LOCATION = 168$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc169:
  StrCmp "Netherlands Antilles" $R0 "" lbl_intrfc170
  FileWrite $4 "LOCATION = 169$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc170:
  StrCmp "New Caledonia" $R0 "" lbl_intrfc171
  FileWrite $4 "LOCATION = 170$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc171:
  StrCmp "New Zealand" $R0 "" lbl_intrfc172
  FileWrite $4 "LOCATION = 171$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc172:
  StrCmp "Nicaragua" $R0 "" lbl_intrfc173
  FileWrite $4 "LOCATION = 172$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc173:
  StrCmp "Niger" $R0 "" lbl_intrfc174
  FileWrite $4 "LOCATION = 173$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc174:
  StrCmp "Nigeria" $R0 "" lbl_intrfc175
  FileWrite $4 "LOCATION = 174$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc175:
  StrCmp "Niue" $R0 "" lbl_intrfc176
  FileWrite $4 "LOCATION = 175$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc176:
  StrCmp "Norfolk Island" $R0 "" lbl_intrfc177
  FileWrite $4 "LOCATION = 176$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc177:
  StrCmp "Northern Mariana Islands" $R0 "" lbl_intrfc178
  FileWrite $4 "LOCATION = 177$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc178:
  StrCmp "Norway" $R0 "" lbl_intrfc179
  FileWrite $4 "LOCATION = 178$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc179:
  StrCmp "Oman" $R0 "" lbl_intrfc180
  FileWrite $4 "LOCATION = 179$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc180:
  StrCmp "Pakistan" $R0 "" lbl_intrfc181
  FileWrite $4 "LOCATION = 180$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc181:
  StrCmp "Palau" $R0 "" lbl_intrfc182
  FileWrite $4 "LOCATION = 181$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc182:
  StrCmp "Palestinian State" $R0 "" lbl_intrfc183
  FileWrite $4 "LOCATION = 182$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc183:
  StrCmp "Palmyra Atoll" $R0 "" lbl_intrfc184
  FileWrite $4 "LOCATION = 183$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc184:
  StrCmp "Panama" $R0 "" lbl_intrfc185
  FileWrite $4 "LOCATION = 184$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc185:
  StrCmp "Papua New Guinea" $R0 "" lbl_intrfc186
  FileWrite $4 "LOCATION = 185$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc186:
  StrCmp "Paracel Islands" $R0 "" lbl_intrfc187
  FileWrite $4 "LOCATION = 186$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc187:
  StrCmp "Paraguay" $R0 "" lbl_intrfc188
  FileWrite $4 "LOCATION = 187$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc188:
  StrCmp "Peru" $R0 "" lbl_intrfc189
  FileWrite $4 "LOCATION = 188$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc189:
  StrCmp "Philippines" $R0 "" lbl_intrfc190
  FileWrite $4 "LOCATION = 189$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc190:
  StrCmp "Pitcairn Islands" $R0 "" lbl_intrfc191
  FileWrite $4 "LOCATION = 190$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc191:
  StrCmp "Poland" $R0 "" lbl_intrfc192
  FileWrite $4 "LOCATION = 191$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc192:
  StrCmp "Portugal" $R0 "" lbl_intrfc193
  FileWrite $4 "LOCATION = 192$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc193:
  StrCmp "Puerto Rico" $R0 "" lbl_intrfc194
  FileWrite $4 "LOCATION = 193$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc194:
  StrCmp "Qatar" $R0 "" lbl_intrfc195
  FileWrite $4 "LOCATION = 194$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc195:
  StrCmp "Reunion" $R0 "" lbl_intrfc196
  FileWrite $4 "LOCATION = 195$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc196:
  StrCmp "Romania" $R0 "" lbl_intrfc197
  FileWrite $4 "LOCATION = 196$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc197:
  StrCmp "Russia" $R0 "" lbl_intrfc198
  FileWrite $4 "LOCATION = 197$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc198:
  StrCmp "Rwanda" $R0 "" lbl_intrfc199
  FileWrite $4 "LOCATION = 198$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc199:
  StrCmp "Saint Helena" $R0 "" lbl_intrfc200
  FileWrite $4 "LOCATION = 199$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc200:
  StrCmp "Saint Kitts and Nevis" $R0 "" lbl_intrfc201
  FileWrite $4 "LOCATION = 200$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc201:
  StrCmp "Saint Lucia" $R0 "" lbl_intrfc202
  FileWrite $4 "LOCATION = 201$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc202:
  StrCmp "Saint Pierre and Miquelon" $R0 "" lbl_intrfc203
  FileWrite $4 "LOCATION = 202$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc203:
  StrCmp "Saint Vincent and the Grenadines" $R0 "" lbl_intrfc204
  FileWrite $4 "LOCATION = 203$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc204:
  StrCmp "Samoa" $R0 "" lbl_intrfc205
  FileWrite $4 "LOCATION = 204$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc205:
  StrCmp "San Marino" $R0 "" lbl_intrfc206
  FileWrite $4 "LOCATION = 205$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc206:
  StrCmp "Sao Tome and Principe" $R0 "" lbl_intrfc207
  FileWrite $4 "LOCATION = 206$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc207:
  StrCmp "Saudi Arabia" $R0 "" lbl_intrfc208
  FileWrite $4 "LOCATION = 207$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc208:
  StrCmp "Senegal" $R0 "" lbl_intrfc209
  FileWrite $4 "LOCATION = 208$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc209:
  StrCmp "Serbia and Montenegro" $R0 "" lbl_intrfc210
  FileWrite $4 "LOCATION = 209$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc210:
  StrCmp "Seychelles" $R0 "" lbl_intrfc211
  FileWrite $4 "LOCATION = 210$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc211:
  StrCmp "Sierra Leone" $R0 "" lbl_intrfc212
  FileWrite $4 "LOCATION = 211$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc212:
  StrCmp "Singapore" $R0 "" lbl_intrfc213
  FileWrite $4 "LOCATION = 212$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc213:
  StrCmp "Slovakia" $R0 "" lbl_intrfc214
  FileWrite $4 "LOCATION = 213$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc214:
  StrCmp "Slovenia" $R0 "" lbl_intrfc215
  FileWrite $4 "LOCATION = 214$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc215:
  StrCmp "Solomon Islands" $R0 "" lbl_intrfc216
  FileWrite $4 "LOCATION = 215$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc216:
  StrCmp "Somalia" $R0 "" lbl_intrfc217
  FileWrite $4 "LOCATION = 216$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc217:
  StrCmp "South Africa" $R0 "" lbl_intrfc218
  FileWrite $4 "LOCATION = 217$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc218:
  StrCmp "South Georgia and South Sandwich Islands" $R0 "" lbl_intrfc219
  FileWrite $4 "LOCATION = 218$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc219:
  StrCmp "Spain" $R0 "" lbl_intrfc220
  FileWrite $4 "LOCATION = 219$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc220:
  StrCmp "Spratly Islands" $R0 "" lbl_intrfc221
  FileWrite $4 "LOCATION = 220$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc221:
  StrCmp "Sri Lanka" $R0 "" lbl_intrfc222
  FileWrite $4 "LOCATION = 221$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc222:
  StrCmp "Sudan" $R0 "" lbl_intrfc223
  FileWrite $4 "LOCATION = 222$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc223:
  StrCmp "Suriname" $R0 "" lbl_intrfc224
  FileWrite $4 "LOCATION = 223$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc224:
  StrCmp "Svalbard" $R0 "" lbl_intrfc225
  FileWrite $4 "LOCATION = 224$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc225:
  StrCmp "Swaziland" $R0 "" lbl_intrfc226
  FileWrite $4 "LOCATION = 225$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc226:
  StrCmp "Sweden" $R0 "" lbl_intrfc227
  FileWrite $4 "LOCATION = 226$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc227:
  StrCmp "Switzerland" $R0 "" lbl_intrfc228
  FileWrite $4 "LOCATION = 227$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc228:
  StrCmp "Syria" $R0 "" lbl_intrfc229
  FileWrite $4 "LOCATION = 228$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc229:
  StrCmp "Taiwan" $R0 "" lbl_intrfc230
  FileWrite $4 "LOCATION = 229$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc230:
  StrCmp "Tajikistan" $R0 "" lbl_intrfc231
  FileWrite $4 "LOCATION = 230$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc231:
  StrCmp "Tanzania" $R0 "" lbl_intrfc232
  FileWrite $4 "LOCATION = 231$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc232:
  StrCmp "Thailand" $R0 "" lbl_intrfc233
  FileWrite $4 "LOCATION = 232$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc233:
  StrCmp "Togo" $R0 "" lbl_intrfc234
  FileWrite $4 "LOCATION = 233$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc234:
  StrCmp "Tokelau" $R0 "" lbl_intrfc235
  FileWrite $4 "LOCATION = 234$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc235:
  StrCmp "Tonga" $R0 "" lbl_intrfc236
  FileWrite $4 "LOCATION = 235$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc236:
  StrCmp "Trinidad and Tobago" $R0 "" lbl_intrfc237
  FileWrite $4 "LOCATION = 236$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc237:
  StrCmp "Tromelin Island" $R0 "" lbl_intrfc238
  FileWrite $4 "LOCATION = 237$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc238:
  StrCmp "Tunisia" $R0 "" lbl_intrfc239
  FileWrite $4 "LOCATION = 238$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc239:
  StrCmp "Turkey" $R0 "" lbl_intrfc240
  FileWrite $4 "LOCATION = 239$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc240:
  StrCmp "Turkmenistan" $R0 "" lbl_intrfc241
  FileWrite $4 "LOCATION = 240$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc241:
  StrCmp "Turks and Caicos Islands" $R0 "" lbl_intrfc242
  FileWrite $4 "LOCATION = 241$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc242:
  StrCmp "Tuvalu" $R0 "" lbl_intrfc243
  FileWrite $4 "LOCATION = 242$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc243:
  StrCmp "Uganda" $R0 "" lbl_intrfc244
  FileWrite $4 "LOCATION = 243$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc244:
  StrCmp "Ukraine" $R0 "" lbl_intrfc245
  FileWrite $4 "LOCATION = 244$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc245:
  StrCmp "United Arab Emirates" $R0 "" lbl_intrfc246
  FileWrite $4 "LOCATION = 245$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc246:
  StrCmp "United Kingdom" $R0 "" lbl_intrfc247
  FileWrite $4 "LOCATION = 246$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc247:
  StrCmp "United States" $R0 "" lbl_intrfc248
  FileWrite $4 "LOCATION = 247$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc248:
  StrCmp "Uruguay" $R0 "" lbl_intrfc249
  FileWrite $4 "LOCATION = 248$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc249:
  StrCmp "Uzbekistan" $R0 "" lbl_intrfc250
  FileWrite $4 "LOCATION = 249$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc250:
  StrCmp "Vanuatu" $R0 "" lbl_intrfc251
  FileWrite $4 "LOCATION = 250$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc251:
  StrCmp "Vatican City (Holy See)" $R0 "" lbl_intrfc252
  FileWrite $4 "LOCATION = 251$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc252:
  StrCmp "Venezuela" $R0 "" lbl_intrfc253
  FileWrite $4 "LOCATION = 252$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc253:
  StrCmp "Vietnam" $R0 "" lbl_intrfc254
  FileWrite $4 "LOCATION = 253$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc254:
  StrCmp "Virgin Islands" $R0 "" lbl_intrfc255
  FileWrite $4 "LOCATION = 254$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc255:
  StrCmp "Wake Island" $R0 "" lbl_intrfc256
  FileWrite $4 "LOCATION = 255$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc256:
  StrCmp "Wallis and Futuna" $R0 "" lbl_intrfc257
  FileWrite $4 "LOCATION = 256$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc257:
  StrCmp "Western Sahara" $R0 "" lbl_intrfc258
  FileWrite $4 "LOCATION = 257$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc258:
  StrCmp "Yemen" $R0 "" lbl_intrfc259
  FileWrite $4 "LOCATION = 258$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc259:
  StrCmp "*Yugoslavia" $R0 "" lbl_intrfc260
  FileWrite $4 "LOCATION = 259$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc260:
  StrCmp "Zambia" $R0 "" lbl_intrfc261
  FileWrite $4 "LOCATION = 260$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc261:
  StrCmp "Zimbabwe" $R0 "" lbl_intrfc262
  FileWrite $4 "LOCATION = 261$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfc262:
  StrCmp "Other" $R0 "" lbl_intrfcdone
  FileWrite $4 "LOCATION = 262$\r$\n"
  Goto lbl_intrfcdone
lbl_intrfcdone:
  FileWrite $4 "$\r$\n"
  ; US Zip
  FileWrite $4 "# If you are located in the United States, please specify your$\r$\n"
  FileWrite $4 "#$\tUS Zip code.$\r$\n"
  !insertmacro MUI_INSTALLOPTIONS_READ $R0 "netiloc.ini" "Field 5" "State"
  FileWrite $4 "USZIP = $R0$\r$\n"
  FileWrite $4 "$\r$\n"
  ; Add Email
  FileWrite $4 "# If you wish to receive a minimal amount of emails updating$\r$\n"
  FileWrite $4 "#$\tyou on NETI@home, please enter your email address below.$\r$\n"
  FileWrite $4 "#$\tNOTE: Your email address will not be associated with the$\r$\n"
  FileWrite $4 "#$\tdata collected.$\r$\n"
  !insertmacro MUI_INSTALLOPTIONS_READ $R0 "netiloc.ini" "Field 8" "State"
  FileWrite $4 "EMAIL = $R0$\r$\n"
  FileClose $4
  ; End neti.conf

  ; If netilog already exists, move it
  IfFileExists "$INSTDIR\netilog" 0 Nonetilog
    Rename /REBOOTOK "$INSTDIR\netilog" "$INSTDIR\netilog.old"
  Nonetilog:


  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\COPYING"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Logparse Version 2\Debug\logparse.exe"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\NETIMap\NetGeoClient.class"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\Debug\neti.exe"
  File "neti.ico"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\NETIMap\NETIMap$1.class"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\NETIMap\NETIMap.class"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\NETIMap\NetiPoint.class"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETITray Version 2\Debug\NETITray.exe"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\NETIMap\world100.gif"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\zlib.dll"
  ;maybe just File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\NETIMap\*.class"

  ; Create logparse.bat
  FileOpen $4 "$INSTDIR\logparse.bat" w
  FileWrite $4 "@echo off$\r$\n"
  FileWrite $4 "cd $\"$INSTDIR$\"$\r$\n"
  FileWrite $4 "if not exist netilog goto error$\r$\n"
  FileWrite $4 ".\logparse|more$\r$\n"
  FileWrite $4 "goto done$\r$\n"
  FileWrite $4 "$\r$\n"
  FileWrite $4 ":error$\r$\n"
  FileWrite $4 "echo ***Log file not found***$\r$\n"
  FileWrite $4 "echo If you have recently started using NETI@home$\r$\n"
  FileWrite $4 "echo the log file may not have been created yet.$\r$\n"
  FileWrite $4 "echo The log file is created the first time you$\r$\n"
  FileWrite $4 "echo send data to the NETI@home server.$\r$\n"
  FileWrite $4 "echo This is done so that the log file contains$\r$\n"
  FileWrite $4 "echo the exact same data sent to the NETI@home server.$\r$\n"
  FileWrite $4 "echo If this error persists or for more information$\r$\n"
  FileWrite $4 "echo please visit http://www.neti.gatech.edu$\r$\n"
  FileWrite $4 "pause$\r$\n"
  FileWrite $4 "$\r$\n"
  FileWrite $4 ":done$\r$\n"
  FileClose $4

  ; Create map.bat
  Call GetJRE
  Pop $R0
  FileOpen $4 "$INSTDIR\map.bat" w
  FileWrite $4 "@echo off$\r$\n"
  FileWrite $4 "cd $\"$INSTDIR$\"$\r$\n"
  FileWrite $4 "$\r$\n"
  FileWrite $4 "if not exist $\"$R0$\" goto sun$\r$\n"
  FileWrite $4 "$\"$R0$\" NETIMap$\r$\n"
  FileWrite $4 "goto done$\r$\n"
  FileWrite $4 "$\r$\n"
  FileWrite $4 ":sun$\r$\n"
  FileWrite $4 "if not exist javaw.exe goto windows$\r$\n"
  FileWrite $4 "javaw NETIMap$\r$\n"
  FileWrite $4 "goto done$\r$\n"
  FileWrite $4 "$\r$\n"
  FileWrite $4 ":windows$\r$\n"
  FileWrite $4 "if not exist \windows\wjview.exe goto nt$\r$\n"
  FileWrite $4 "wjview NETIMap$\r$\n"
  FileWrite $4 "goto done$\r$\n"
  FileWrite $4 "$\r$\n"
  FileWrite $4 ":nt$\r$\n"
  FileWrite $4 "if not exist \winnt\wjview.exe goto system32$\r$\n"
  FileWrite $4 "wjview NETIMap$\r$\n"
  FileWrite $4 "goto done$\r$\n"
  FileWrite $4 "$\r$\n"
  FileWrite $4 ":system32$\r$\n"
  FileWrite $4 "if not exist \windows\system32\wjview.exe goto ntsys32$\r$\n"
  FileWrite $4 "wjview NETIMap$\r$\n"
  FileWrite $4 "goto done$\r$\n"
  FileWrite $4 "$\r$\n"
  FileWrite $4 ":ntsys32$\r$\n"
  FileWrite $4 "if not exist \winnt\system32\wjview.exe goto error$\r$\n"
  FileWrite $4 "wjview NETIMap$\r$\n"
  FileWrite $4 "goto done$\r$\n"
  FileWrite $4 "$\r$\n"
  FileWrite $4 ":error$\r$\n"
  FileWrite $4 "echo No Java found (wjview (Microsoft) or javaw (Sun))$\r$\n"
  FileWrite $4 "echo Try downloading Java from Sun at$\r$\n"
  FileWrite $4 "http://java.sun.com/downloads/index.html$\r$\n"
  FileWrite $4 "$\r$\n"
  FileWrite $4 ":done$\r$\n"
  FileClose $4



;create start-menu items
  CreateDirectory "$SMPROGRAMS\NETI@home"
  CreateShortCut "$SMPROGRAMS\NETI@home\NETIMap.lnk" "$INSTDIR\map.bat" "" "$INSTDIR\neti.ico" 0 "" "" "A Graphical Representation of Internet Hosts that You Are Contacting"
  CreateShortCut "$SMPROGRAMS\NETI@home\NETI@home Controls.lnk" "$INSTDIR\NETITray.exe" "" "$INSTDIR\neti.ico" 0 "" "" "Controls for the NETI@home program"
  CreateShortCut "$SMPROGRAMS\NETI@home\NETI@home Logparse.lnk" "$INSTDIR\logparse.bat" "" "$INSTDIR\neti.ico" 0 "" "" "Parses and Displays the Log File"
  CreateShortCut "$SMSTARTUP\NETI@home Controls.lnk" "$INSTDIR\NETITray.exe" "" "$INSTDIR\neti.ico" 0 "" "" "Controls for the NETI@home program"
 
;Store installation folder
  WriteRegStr HKLM "Software\NETI@home" "" $INSTDIR

;write registry information (only for 95, 98, Me)
  Call GetWindowsVersion
  Pop $R0
  StrCmp "95" $R0 lbl_95_98_Me
  StrCmp "98" $R0 lbl_95_98_Me
  StrCmp "ME" $R0 lbl_95_98_Me lbl_NT_2000_XP
lbl_95_98_Me:
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\RunServices" "NETI" "$INSTDIR\neti.exe"
lbl_NT_2000_XP:

;install service (only for NT, 2000, XP)
  StrCmp "95" $R0 lbl_95_98_Me_Serv
  StrCmp "98" $R0 lbl_95_98_Me_Serv
  StrCmp "ME" $R0 lbl_95_98_Me_Serv
  ExecWait '"$INSTDIR\neti.exe" /SERVICE /INSTALL'
lbl_95_98_Me_Serv:

;write uninstall information to the registry
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\NETI@home" "DisplayName" "NETI@home (remove only)"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\NETI@home" "UninstallString" "$INSTDIR\NETIuninstall.exe"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\NETI@home" "DisplayIcon" "$INSTDIR\neti.ico 0"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\NETI@home" "HelpLink" "mailto:neti@ece.gatech.edu"
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\NETI@home" "NoModify" "1"
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\NETI@home" "NoRepair" "1"
 
;Create uninstaller
  WriteUninstaller "$INSTDIR\NETIuninstall.exe"

;Set reboot flag so that service will be started
  SetRebootFlag true

SectionEnd

Section "Source" SecSource

;Add files
  SetOutPath "$INSTDIR\src"	;Source Directory
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\AUTHORS"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\cdefs.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\checksum.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\COPYING"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\debug.cpp"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\debug.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\decode.cpp"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\decode.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\locations.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\logparse.cpp"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\neti-2.0-1.spec"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\neti.7"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\neti.conf"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\neti.cpp"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\neti.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\neti.script"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\netistats.cpp"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\netistats.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\README"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\snprintf.cpp"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\snprintf.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\strlcpyu.cpp"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\strlcpyu.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\timersub.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\util.cpp"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\util.h"
  SetOutPath "$INSTDIR\src\autoconf"	;Source Directory
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\autoconf\configure.in"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\autoconf\Makefile.am"
  SetOutPath "$INSTDIR\src\mac"		;Source Directory
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\mac\config.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\mac\createmacpkg.sh"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\mac\libpcap.a"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\mac\neti"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\mac\pcap.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\mac\pcap-namedb.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\mac\ReadMe.txt"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\mac\StartupParameters.plist"
  SetOutPath "$INSTDIR\src\NETIMap"	;Source Directory
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\NETIMap\NetGeoClient.java"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\NETIMap\NETIMap.java"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\NETIMap\world100.gif"
  SetOutPath "$INSTDIR\src\NETITray"	;Source Directory
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\NETITray\neti.ico"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\NETITray\netioff.ico"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\NETITray\netioffupdate.ico"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\NETITray\netiupdate.ico"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\NETITray\NETITray.cpp"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\NETITray\NETITray.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\NETITray\NETITray.rc"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\NETITray\resource.h"
  SetOutPath "$INSTDIR\src\win32\WIN32-Code"	;Source Directory
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Code\getopt.cpp"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Code\inet_aton.cpp"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Code\misc.cpp"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Code\syslog.cpp"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Code\win32_service.cpp"
  SetOutPath "$INSTDIR\src\win32\WIN32-Includes"	;Source Directory
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Includes\config.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Includes\getopt.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Includes\gnuc.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Includes\ip6_misc.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Includes\pcap.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Includes\pcap-stdinc.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Includes\stdint.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Includes\syslog.h"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Includes\unistd.h"
  SetOutPath "$INSTDIR\src\win32\WIN32-Includes\NET"	;Source Directory
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Includes\NET\bpf.h"
  SetOutPath "$INSTDIR\src\win32\WIN32-Includes\NETINET"	;Source Directory
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Includes\NETINET\IF_ETHER.H"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Includes\NETINET\IN_SYSTM.H"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Includes\NETINET\IP.H"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Includes\NETINET\IP_ICMP.H"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Includes\NETINET\IP_VAR.H"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Includes\NETINET\TCP.H"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Includes\NETINET\TCPIP.H"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Includes\NETINET\TCP_VAR.H"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Includes\NETINET\UDP.H"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\win32\WIN32-Includes\NETINET\UDP_VAR.H"
  SetOutPath "$INSTDIR\src\windows"	;Source Directory
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\windows\neti.ico"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\windows\neti.nsi"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\windows\netipcap.ini"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\windows\netiprop.ini"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\windows\netidev.ini"
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\windows\netiloc.ini"
  SetOutPath "$INSTDIR\src\windows\devselect"	;Source Directory
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\windows\devselect\devselect.cpp"

;create start-menu items
  CreateShortCut "$SMPROGRAMS\NETI@home\NETI@home Source.lnk" "$INSTDIR\src" "" "" "" "" "" "NETI@home Source Code"

SectionEnd


;--------------------------------
;Descriptions
; Need for the COMPONENTS page

  ;Language strings
  LangString DESC_SecSource ${LANG_ENGLISH} "NETI@home Source Code"

  ;Assign language strings to sections
  !insertmacro MUI_FUNCTION_DESCRIPTION_BEGIN
    !insertmacro MUI_DESCRIPTION_TEXT ${SecSource} $(DESC_SecSource)
  !insertmacro MUI_FUNCTION_DESCRIPTION_END

;--------------------------------

;--------------------------------    
;Uninstaller Section  
Section "Uninstall"
   
;Set for All Users
  SetShellVarContext all
  SetOutPath "$INSTDIR"

;uninstall service (only for NT, 2000, XP)
  StrCmp "95" $R0 lbl_95_98_Me_Serv
  StrCmp "98" $R0 lbl_95_98_Me_Serv
  StrCmp "ME" $R0 lbl_95_98_Me_Serv
; ExecWait "net stop neti"
  ExecWait '"$INSTDIR\neti.exe" /SERVICE /UNINSTALL'
lbl_95_98_Me_Serv:

;Delete Files
  Delete /REBOOTOK "$INSTDIR\src\autoconf\*.*"
  RMDir /REBOOTOK "$INSTDIR\src\autoconf"
  Delete /REBOOTOK "$INSTDIR\src\mac\*.*"
  RMDir /REBOOTOK "$INSTDIR\src\mac"
  Delete /REBOOTOK "$INSTDIR\src\NETIMap\*.*"
  RMDir /REBOOTOK "$INSTDIR\src\NETIMap"
  Delete /REBOOTOK "$INSTDIR\src\NETITray\*.*"
  RMDir /REBOOTOK "$INSTDIR\src\NETITray"
  Delete /REBOOTOK "$INSTDIR\src\win32\WIN32-Code\*.*"
  RMDir /REBOOTOK "$INSTDIR\src\win32\WIN32-Code"
  Delete /REBOOTOK "$INSTDIR\src\win32\WIN32-Includes\NET\*.*"
  RMDir /REBOOTOK "$INSTDIR\src\win32\WIN32-Includes\NET"
  Delete /REBOOTOK "$INSTDIR\src\win32\WIN32-Includes\NETINET\*.*"
  RMDir /REBOOTOK "$INSTDIR\src\win32\WIN32-Includes\NETINET"
  Delete /REBOOTOK "$INSTDIR\src\win32\WIN32-Includes\*.*"
  RMDir /REBOOTOK "$INSTDIR\src\win32\WIN32-Includes"
  Delete /REBOOTOK "$INSTDIR\src\win32\*.*"
  RMDir /REBOOTOK "$INSTDIR\src\win32"
  Delete /REBOOTOK "$INSTDIR\src\windows\devselect\*.*"
  RMDir /REBOOTOK "$INSTDIR\src\windows\devselect"
  Delete /REBOOTOK "$INSTDIR\src\windows\*.*"
  RMDir /REBOOTOK "$INSTDIR\src\windows"
  Delete /REBOOTOK "$INSTDIR\src\*.*"
  RMDir /REBOOTOK "$INSTDIR\src"
  Delete /REBOOTOK "$INSTDIR\*.*"

;Remove the installation directory
  RMDir /REBOOTOK "$INSTDIR"
  
;Delete Start Menu Shortcuts
  Delete /REBOOTOK "$SMPROGRAMS\NETI@home\*.*"
  RMDir  /REBOOTOK "$SMPROGRAMS\NETI@home"
  Delete /REBOOTOK "$SMSTARTUP\NETI@home Controls.lnk"
  
;Delete Uninstaller And Uninstall Registry Entries
  DeleteRegKey HKLM "SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\NETI@home"
  Delete /REBOOTOK "$INSTDIR\NETIuninstall.exe"

;Delete Installation Folder
  DeleteRegKey /ifempty HKLM "Software\NETI@home"

;Only for 95, 98, Me
  Call un.GetWindowsVersion
  Pop $R0
  StrCmp "95" $R0 lbl_UN_95_98_Me
  StrCmp "98" $R0 lbl_UN_95_98_Me
  StrCmp "ME" $R0 lbl_UN_95_98_Me lbl_UN_NT_2000_XP
lbl_UN_95_98_Me:
  DeleteRegValue HKLM "SOFTWARE\Microsoft\Windows\CurrentVersion\RunServices" "NETI"
lbl_UN_NT_2000_XP:

SectionEnd


;--------------------------------    
;MessageBox Section


;Function that calls a messagebox when installation finished correctly
;Function .onInstSuccess
;  StrCpy $0 "NETI@home has successfully been installed.$\r$\n"
;  StrCpy $0 "$0$\r$\n"
;  StrCpy $0 "$0$\r$\n"
;  StrCpy $0 "$0NETI@home also requires WinPcap 3.0 or greater to be installed on this machine.$\r$\n"
;  StrCpy $0 "$0WinPcap can be downloaded from:$\r$\n"
;  StrCpy $0 "$0    http://winpcap.polito.it/ $\r$\n"
;  MessageBox MB_OK $0
;FunctionEnd


;Function un.onUninstSuccess
;  MessageBox MB_OK "You have successfully uninstalled NETI@home."
;FunctionEnd

Function .onInit
  ; Extract InstallOptions INI files
  !ifdef INSTALLPCAP
  !insertmacro MUI_INSTALLOPTIONS_EXTRACT "netipcap.ini"
  !endif
  !insertmacro MUI_INSTALLOPTIONS_EXTRACT "netiprop.ini"
  !insertmacro MUI_INSTALLOPTIONS_EXTRACT "netidev.ini"
  !insertmacro MUI_INSTALLOPTIONS_EXTRACT "netiloc.ini"

;  MessageBox MB_OK "If you have older versions of NETI@home installed, please uninstall them before proceeding.$\r$\nNOTE: You must already have WinPcap 3.0 or greater installed.$\r$\nWinPcap can be downloaded from:$\r$\n    http://winpcap.polito.it/ "
  MessageBox MB_OK "If you have older versions of NETI@home installed, please uninstall them before proceeding."
FunctionEnd

; Strings for Custom Pages
LangString TEXT_DEV_TITLE ${LANG_ENGLISH} "Device Selection Page"
LangString TEXT_DEV_SUBTITLE ${LANG_ENGLISH} "NOTE: This setting can be changed later from the file neti.conf, devices can be listed with $\"neti -W$\""
LangString TEXT_PROP_TITLE ${LANG_ENGLISH} "Properties Selection Page"
LangString TEXT_PROP_SUBTITLE ${LANG_ENGLISH} "NOTE: These settings can be changed later from the file neti.conf"
LangString TEXT_LOC_TITLE ${LANG_ENGLISH} "Location Selection Page"
LangString TEXT_LOC_SUBTITLE ${LANG_ENGLISH} "NOTE: These settings can be changed later from the file neti.conf"
!ifdef INSTALLPCAP
LangString TEXT_PCAP_TITLE ${LANG_ENGLISH} "WinPcap Installation Page"
LangString TEXT_PCAP_SUBTITLE ${LANG_ENGLISH} "WinPcap must be installed for NETI@home to function correctly"

Function WinPcap
  SetOutPath $PLUGINSDIR
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home Version 2\windows\WinPcap_3_1_beta4_nogui_noreboot_nobanner.exe"
  ExecWait WinPcap_3_1_beta4_nogui_noreboot_nobanner.exe
  !insertmacro MUI_HEADER_TEXT "$(TEXT_PCAP_TITLE)" "$(TEXT_PCAP_SUBTITLE)"
  !insertmacro MUI_INSTALLOPTIONS_DISPLAY "netipcap.ini"
FunctionEnd
!endif

Function SetDevice	; Custom Page's Function
  SetOutPath $PLUGINSDIR
; Maybe one day turn devselect into an NSIS plugin
  File "c:\documents and settings\crsimps\My Documents\Visual Studio Projects\NETI@home devselect\Debug\devselect.exe"
  ExecWait '"devselect.exe" $PLUGINSDIR\temp.txt'
  FileOpen $R0 "$PLUGINSDIR\temp.txt" "r"
  FileRead $R0 $R1 255
  FileClose $R0
  WriteINIStr "$PLUGINSDIR\netidev.ini" "Field 2" "ListItems" $R1
  !insertmacro MUI_HEADER_TEXT "$(TEXT_DEV_TITLE)" "$(TEXT_DEV_SUBTITLE)"
; If want return value use MUI_INSTALLOPTIONS_DISPLAY_RETURN - will be on stack
  !insertmacro MUI_INSTALLOPTIONS_DISPLAY "netidev.ini"
FunctionEnd

Function SetProperties	; Custom Page's Function
  !insertmacro MUI_HEADER_TEXT "$(TEXT_PROP_TITLE)" "$(TEXT_PROP_SUBTITLE)"
; If want return value use MUI_INSTALLOPTIONS_DISPLAY_RETURN - will be on stack
  !insertmacro MUI_INSTALLOPTIONS_DISPLAY "netiprop.ini"
FunctionEnd

Function SetLocation	; Custom Page's Function
  !insertmacro MUI_HEADER_TEXT "$(TEXT_LOC_TITLE)" "$(TEXT_LOC_SUBTITLE)"
; If want return value use MUI_INSTALLOPTIONS_DISPLAY_RETURN - will be on stack
  !insertmacro MUI_INSTALLOPTIONS_DISPLAY "netiloc.ini"
FunctionEnd

; GetWindowsVersion
;
; Based on Yazno's function, http://yazno.tripod.com/powerpimpit/
; Updated by Joost Verburg
;
; Returns on top of stack
;
; Windows Version (95, 98, ME, NT x.x, 2000, XP, 2003)
; or
; '' (Unknown Windows Version)
;
; Usage:
;   Call GetWindowsVersion
;   Pop $R0
;   ; at this point $R0 is "NT 4.0" or whatnot

Function GetWindowsVersion

  Push $R0
  Push $R1

  ReadRegStr $R0 HKLM \
  "SOFTWARE\Microsoft\Windows NT\CurrentVersion" CurrentVersion

  IfErrors 0 lbl_winnt

  ; we are not NT
  ReadRegStr $R0 HKLM \
  "SOFTWARE\Microsoft\Windows\CurrentVersion" VersionNumber

  StrCpy $R1 $R0 1
  StrCmp $R1 '4' 0 lbl_error

  StrCpy $R1 $R0 3

  StrCmp $R1 '4.0' lbl_win32_95
  StrCmp $R1 '4.9' lbl_win32_ME lbl_win32_98

  lbl_win32_95:
    StrCpy $R0 '95'
  Goto lbl_done

  lbl_win32_98:
    StrCpy $R0 '98'
  Goto lbl_done

  lbl_win32_ME:
    StrCpy $R0 'ME'
  Goto lbl_done

  lbl_winnt:

  StrCpy $R1 $R0 1

  StrCmp $R1 '3' lbl_winnt_x
  StrCmp $R1 '4' lbl_winnt_x

  StrCpy $R1 $R0 3

  StrCmp $R1 '5.0' lbl_winnt_2000
  StrCmp $R1 '5.1' lbl_winnt_XP
  StrCmp $R1 '5.2' lbl_winnt_2003 lbl_error

  lbl_winnt_x:
    StrCpy $R0 "NT $R0" 6
  Goto lbl_done

  lbl_winnt_2000:
    Strcpy $R0 '2000'
  Goto lbl_done

  lbl_winnt_XP:
    Strcpy $R0 'XP'
  Goto lbl_done

  lbl_winnt_2003:
    Strcpy $R0 '2003'
  Goto lbl_done

  lbl_error:
    Strcpy $R0 ''
  lbl_done:

  Pop $R1
  Exch $R0

FunctionEnd

; GetWindowsVersion
;
; Based on Yazno's function, http://yazno.tripod.com/powerpimpit/
; Updated by Joost Verburg
;
; Returns on top of stack
;
; Windows Version (95, 98, ME, NT x.x, 2000, XP, 2003)
; or
; '' (Unknown Windows Version)
;
; Usage:
;   Call GetWindowsVersion
;   Pop $R0
;   ; at this point $R0 is "NT 4.0" or whatnot

Function un.GetWindowsVersion

  Push $R0
  Push $R1

  ReadRegStr $R0 HKLM \
  "SOFTWARE\Microsoft\Windows NT\CurrentVersion" CurrentVersion

  IfErrors 0 lbl_winnt

  ; we are not NT
  ReadRegStr $R0 HKLM \
  "SOFTWARE\Microsoft\Windows\CurrentVersion" VersionNumber

  StrCpy $R1 $R0 1
  StrCmp $R1 '4' 0 lbl_error

  StrCpy $R1 $R0 3

  StrCmp $R1 '4.0' lbl_win32_95
  StrCmp $R1 '4.9' lbl_win32_ME lbl_win32_98

  lbl_win32_95:
    StrCpy $R0 '95'
  Goto lbl_done

  lbl_win32_98:
    StrCpy $R0 '98'
  Goto lbl_done

  lbl_win32_ME:
    StrCpy $R0 'ME'
  Goto lbl_done

  lbl_winnt:

  StrCpy $R1 $R0 1

  StrCmp $R1 '3' lbl_winnt_x
  StrCmp $R1 '4' lbl_winnt_x

  StrCpy $R1 $R0 3

  StrCmp $R1 '5.0' lbl_winnt_2000
  StrCmp $R1 '5.1' lbl_winnt_XP
  StrCmp $R1 '5.2' lbl_winnt_2003 lbl_error

  lbl_winnt_x:
    StrCpy $R0 "NT $R0" 6
  Goto lbl_done

  lbl_winnt_2000:
    Strcpy $R0 '2000'
  Goto lbl_done

  lbl_winnt_XP:
    Strcpy $R0 'XP'
  Goto lbl_done

  lbl_winnt_2003:
    Strcpy $R0 '2003'
  Goto lbl_done

  lbl_error:
    Strcpy $R0 ''
  lbl_done:

  Pop $R1
  Exch $R0

FunctionEnd

; GetJRE
;
; Based on Baz's function, http://nsis.sourceforge.net/archive/nsisweb.php?page=326&instances=0,64
; Also modified by Pac, http://nsis.sourceforge.net/archive/nsisweb.php?page=373&instances=0,64
;
; Returns on top of stack
;
;  Find JRE (Java.exe)
;  1 - in JAVA_HOME environment variable
;  2 - in the registry
;  3 - assume java.exe in current dir or PATH
Function GetJRE

  Push $R0
  Push $R1

  ClearErrors
  ReadEnvStr $R0 "JAVA_HOME"
  StrCpy $R0 "$R0\bin\javaw.exe"
  IfErrors 0 JreFound

  ClearErrors
  ReadRegStr $R1 HKLM "SOFTWARE\JavaSoft\Java Runtime Environment" "CurrentVersion"
  ReadRegStr $R0 HKLM "SOFTWARE\JavaSoft\Java Runtime Environment\$R1" "JavaHome"
  StrCpy $R0 "$R0\bin\javaw.exe"

  IfErrors 0 JreFound
  StrCpy $R0 "javaw.exe"
        
 JreFound:
  Pop $R1
  Exch $R0
FunctionEnd

;eof
